@@ -34,9 +34,13 @@
 #include "CResources.h"
 #include "IDevice.h"
 #include "CDlgCreateWorldBasemap.h"
-#include "CUndoStack.h"
+#include "CUndoStackModel.h"
+#include "CUndoStackView.h"
 #include "CTrackUndoCommandDeletePts.h"
 #include "CTrackUndoCommandPurgePts.h"
+#ifdef PLOT_3D
+#include "CMap3D.h"
+#endif
 
 CActions::CActions(QObject *parent) :
 QObject(parent), parent(parent)
@@ -69,23 +73,22 @@ QObject(parent), parent(parent)
 
 #ifdef PLOT_3D
     createAction(tr("ESC"),":/icons/iconBack16x16",tr("&Close"),"aCloseMap3D",tr("Close 3D view."));
-    createAction(tr("F1"),0,tr("&Flat / 3D Mode"),"aMap3DMode",tr("Toggle between 3D track only and full map surface model."));
-    createAction(tr("F2"),":/icons/iconInc16x16",tr("&Inc. Elevation"),"aMap3DZoomPlus",tr("Make elevations on the map higher as they are."));
-    createAction(tr("F3"),":/icons/iconDec16x16",tr("&Dec. Elevation"),"aMap3DZoomMinus",tr("Make elevations on the map lower as they are."));
-    createAction(tr("F4"),":/icons/iconLight16x16",tr("&Lighting On/Off"), "aMap3DLighting",tr("Turn on/off lighting."));
-    createAction(tr("F5"),":/icons/iconTrack16x16",tr("&Trackmode"), "aMap3DTrackmode",tr("Glue point of view to track."));
+    createAction(tr("F1"),0,tr("3D / 2D"),"aMap3DMode",tr("Toggle between 3D and 2D map."));
+    createAction(tr("F2"),0,tr("FPV / Rot."),"aMap3DFPVMode",tr("Toggle between first person view and rotation mode."));
+    createAction(tr("F3"),":/icons/iconLight16x16",tr("Lighting On/Off"), "aMap3DLighting",tr("Turn on/off lighting."));
+    createAction(tr("F4"),":/icons/iconTrack16x16",tr("Trackmode"), "aMap3DTrackMode",tr("Glue point of view to track."));
 #endif
     //
     createAction(tr("F5"), ":/icons/iconAdd16x16", tr("&New Waypoint"), "aNewWpt", tr("Create a new user waypoint. The default position will be the current cursor position."));
     createAction(tr("F6"), ":/icons/iconEdit16x16", tr("&Edit Waypoint"), "aEditWpt", tr("Switch cursor to 'Edit Waypoint' mode. Point-n-click to edit a waypoint."));
-    createAction(tr("F7"), ":/icons/iconWptMove16x16", tr("&Move Waypoint"), "aMoveWpt", tr("Switch cursor to 'Move Waypoint' mode. Point-click-move-click to move a waypoint. Use the right mouse button to abort. It is ok to leave 'Move Waypoint' mode and to resume."));
+    createAction(tr("F7"), ":/icons/iconMove16x16", tr("&Move Waypoint"), "aMoveWpt", tr("Switch cursor to 'Move Waypoint' mode. Point-click-move-click to move a waypoint. Use the right mouse button to abort. It is ok to leave 'Move Waypoint' mode and to resume."));
 #ifdef HAS_EXIF
     createAction(tr("F8"),":/icons/iconRaster16x16",tr("From &Images..."),"aImageWpt",tr("Create waypoints from geo-referenced images in a path."));
 #endif
     createAction(tr("F9"), ":/icons/iconUpload16x16", tr("U&pload"), "aUploadWpt", tr("Upload waypoints to device."));
     createAction(tr("F10"), ":/icons/iconDownload16x16", tr("Down&load"), "aDownloadWpt", tr("Download waypoints from device."));
     //
-    createAction(tr("F5"), ":/icons/iconAdd16x16", tr("Combine &Tracks"), "aCombineTrack", tr("Combine multiple selected tracks to one."));
+    createAction(tr("F5"), ":/icons/iconAdd16x16", tr("Join &Tracks"), "aCombineTrack", tr("Join multiple selected tracks to one."));
     createAction(tr("F6"), ":/icons/iconEdit16x16", tr("&Edit Track"), "aEditTrack", tr("Toggle track edit dialog."));
     createAction(tr("F7"), ":/icons/iconEditCut16x16", tr("&Split Track"), "aCutTrack", tr("Split a track into pieces."));
     createAction(tr("F8"), ":/icons/iconSelect16x16", tr("&Select Points"), "aSelTrack", tr("Select track points by rectangle."));
@@ -384,34 +387,10 @@ void CActions::funcCloseMap3D()
 }
 
 
-void CActions::funcMap3DZoomPlus()
-{
-#ifdef PLOT_3D
-    CMap3DWidget * map = CMapDB::self().getMap3D();
-    if(map)
-    {
-        map->eleZoomIn();
-    }
-#endif
-}
-
-
-void CActions::funcMap3DZoomMinus()
-{
-#ifdef PLOT_3D
-    CMap3DWidget * map = CMapDB::self().getMap3D();
-    if(map)
-    {
-        map->eleZoomOut();
-    }
-#endif
-}
-
-
 void CActions::funcMap3DLighting()
 {
 #ifdef PLOT_3D
-    CMap3DWidget * map = CMapDB::self().getMap3D();
+    CMap3D * map = CMapDB::self().getMap3D();
     map->lightTurn();
 #endif
 }
@@ -420,21 +399,34 @@ void CActions::funcMap3DLighting()
 void CActions::funcMap3DMode()
 {
 #ifdef PLOT_3D
-    CMap3DWidget * map = CMapDB::self().getMap3D();
+    CMap3D * map = CMapDB::self().getMap3D();
     if(map)
     {
-        map->changeMode();
+        map->slotChange3DMode();
     }
 #endif
 }
 
-void CActions::funcMap3DTrackmode()
+
+void CActions::funcMap3DFPVMode()
 {
 #ifdef PLOT_3D
-    CMap3DWidget * map = CMapDB::self().getMap3D();
+    CMap3D * map = CMapDB::self().getMap3D();
     if(map)
     {
-        map->changeTrackmode();
+        map->slotChange3DFPVMode();
+    }
+#endif
+}
+
+
+void CActions::funcMap3DTrackMode()
+{
+#ifdef PLOT_3D
+    CMap3D * map = CMapDB::self().getMap3D();
+    if(map)
+    {
+        map->slotChange3DTrackMode();
     }
 #endif
 }
@@ -512,21 +504,22 @@ void CActions::funcDownloadTrack()
 
 void CActions::funcTrackPurgeSelection()
 {
+    qDebug() << "funcTrackPurgeSelection";
     CTrack *track = CTrackDB::self().highlightedTrack();
     if (track)
-        CUndoStack::getInstance()->push(new CTrackUndoCommandPurgePts(track));
+    {
+        CUndoStackModel::getInstance()->push(new CTrackUndoCommandPurgePts(track));
+    }
 }
 
 
 void CActions::funcDeleteTrackSelection()
 {
+    qDebug() << "funcDeleteTrackSelection";
     CTrack *track = CTrackDB::self().highlightedTrack();
     if (track)
     {
-        CUndoStack::getInstance()->beginMacro(tr("Delete Selection"));
-        CUndoStack::getInstance()->push(new CTrackUndoCommandPurgePts(track));
-        CUndoStack::getInstance()->push(new CTrackUndoCommandDeletePts(track));
-        CUndoStack::getInstance()->endMacro();
+        CUndoStackModel::getInstance()->push(new CTrackUndoCommandPurgePts(track));
     }
 }
 
@@ -644,7 +637,7 @@ void CActions::funcPasteFromClipboard()
 
 void CActions::funcRedo()
 {
-    CUndoStack::getInstance()->redo();
+    CUndoStackModel::getInstance()->redo();
     //    emit CTrackDB::m_self.sigChanged();
     //    emit CTrackDB::m_self->sigModified();
 }
@@ -652,7 +645,7 @@ void CActions::funcRedo()
 
 void CActions::funcUndo()
 {
-    CUndoStack::getInstance()->undo();
+    CUndoStackModel::getInstance()->undo();
     //    emit CTrackDB::m_self()->sigChanged();
     //    emit CTrackDB::m_self()->sigModified();
 }
