@@ -68,10 +68,9 @@ class CActions : public QObject
 
         void funcCloseMap3D();
         void funcMap3DMode();
-        void funcMap3DZoomPlus();
-        void funcMap3DZoomMinus();
+        void funcMap3DFPVMode();
         void funcMap3DLighting();
-        void funcMap3DTrackmode();
+        void funcMap3DTrackMode();
 
         void funcNewWpt();
         void funcEditWpt();
