@@ -164,7 +164,7 @@ void CCreateMapGeoTiff::slotOpenFile()
     QSettings cfg;
     path = QDir(cfg.value("path/create",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.png *.gif)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.tiff *.png *.gif)"), 0, QFileDialog::DontUseNativeDialog);
     if(filename.isEmpty()) return;
 
     CMapDB::self().openMap(filename, true, *theMainWindow->getCanvas());
@@ -208,7 +208,7 @@ void CCreateMapGeoTiff::slotOutFile()
     QSettings cfg;
     path = QDir(cfg.value("path/create",path.path()).toString());
 
-    QString filename = QFileDialog::getSaveFileName(0, tr("Save result as..."),path.filePath(labelOutputFile->text()), tr("GeoTiff (*.tif)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getSaveFileName(0, tr("Save result as..."),path.filePath(labelOutputFile->text()), tr("GeoTiff (*.tif *.tiff)"), 0, QFileDialog::DontUseNativeDialog);
     if(filename.isEmpty()) return;
 
     labelOutputFile->setText(filename);
@@ -737,10 +737,10 @@ void CCreateMapGeoTiff::slotGoOn()
 
     textBrowser->clear();
     textBrowser->setTextColor(Qt::black);
-    textBrowser->append("gdal_translate " +  args.join(" ") + "\n");
+    textBrowser->append(GDALTRANSLATE " " +  args.join(" ") + "\n");
 
     state = eTranslate;
-    cmd.start("gdal_translate", args);
+    cmd.start(GDALTRANSLATE, args);
 
     enableStep3();
 }
@@ -802,9 +802,9 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         args << tmpfile2->fileName();
 
         textBrowser->setTextColor(Qt::black);
-        textBrowser->append("gdalwarp " +  args.join(" ") + "\n");
+        textBrowser->append(GDALWARP " " +  args.join(" ") + "\n");
 
-        cmd.start("gdalwarp", args);
+        cmd.start(GDALWARP, args);
         return;
     }
     if(state == eWarp)
@@ -823,9 +823,9 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         args << labelOutputFile->text();
 
         textBrowser->setTextColor(Qt::black);
-        textBrowser->append("gdal_translate " +  args.join(" ") + "\n");
+        textBrowser->append(GDALTRANSLATE " " +  args.join(" ") + "\n");
 
-        cmd.start("gdal_translate", args);
+        cmd.start(GDALTRANSLATE, args);
         return;
     }
     cleanupTmpFiles();
