@@ -425,6 +425,7 @@ void CGarminExport::slotStart()
     quint16 blockcnt  = 0;
     QByteArray mapsourc;
     QDataStream mps(&mapsourc,QIODevice::WriteOnly);
+    mps.setVersion(QDataStream::Qt_4_5);
     mps.setByteOrder(QDataStream::LittleEndian);
 
     pushExport->setEnabled(false);
@@ -501,9 +502,11 @@ void CGarminExport::slotStart()
         while(map != maps.end())
         {
             mps << quint8('F');
-            mps << quint16(5);
+            mps << quint16(5 + map->map.toAscii().size());
             // I suspect this should really be the basic file name of the .img set:
             mps << map->fid << map->pid;
+
+            mps.writeRawData(map->map.toAscii(),map->map.toAscii().size());
             mps.writeRawData("\0",1);
 
             if(!map->key.isEmpty())
@@ -760,6 +763,7 @@ void CGarminExport::slotStart()
         {
             if(!map->typ.isEmpty())
             {
+                writeStdout(map->typ);
                 QFile file(map->typ);
                 file.open(QIODevice::ReadOnly);
                 QByteArray data = file.readAll();
