@@ -23,6 +23,7 @@
 #include "Platform.h"
 #include "IMap.h"
 #include "CMapDB.h"
+#include "QFileExt.h"
 
 #include <QtGui>
 #include <QSqlDatabase>
@@ -51,18 +52,42 @@ CGarminTile::~CGarminTile()
 }
 
 
-void CGarminTile::readFile(QFile& file, quint32 offset, quint32 size, QByteArray& data)
+void CGarminTile::readFile(QFileExt& file, quint32 offset, quint32 size, QByteArray& data)
 {
-    file.seek(offset);
-    data = file.read(size);
-
-    if((quint32)data.size() != size)
+    if(offset + size > file.size())
     {
         throw exce_t(eErrOpen, tr("Failed to read: ") + filename);
     }
 
-    quint8 * p = (quint8*)data.data();
-    for(quint32 i = 0; i < size; ++i)
+    // wenn mask == 0 ist kein xor noetig
+    if(mask == 0)
+    {
+        data = QByteArray::fromRawData(file.data(offset), size);
+        return;
+    }
+
+    // TODO: dieses copy is unnoetig
+    data = QByteArray::fromRawData(file.data(offset), size);
+
+#ifdef HOST_IS_64_BIT
+    quint64 * p64 = (quint64*)data.data();
+    for(quint32 i = 0; i < size/8; ++i)
+    {
+        *p64++ ^= mask64;
+    }
+    quint32 rest = size % 8;
+    quint8 * p = (quint8*)p64;
+#else
+    quint32 * p32 = (quint32*)data.data();
+    for(quint32 i = 0; i < size/4; ++i)
+    {
+        *p32++ ^= mask32;
+    }
+    quint32 rest = size % 4;
+    quint8 * p = (quint8*)p32;
+#endif
+
+    for(quint32 i = 0; i < rest; ++i)
     {
         *p++ ^= mask;
     }
@@ -78,12 +103,24 @@ void CGarminTile::readBasics(const QString& fn)
     qint64 fsize    = QFileInfo(fn).size();
 
     //     qDebug() << "++++" << filename << "++++";
-    QFile file(filename);
+    QFileExt file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
         throw exce_t(eErrOpen, tr("Failed to open: ") + filename);
     }
-    file.read((char*)&mask, 1);
+    mask = (quint8)*file.data(0);
+
+    mask32   = mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+
+    mask64   = mask32;
+    mask64 <<= 32;
+    mask64  |= mask32;
 
     //     {
     //         QByteArray data;
@@ -242,8 +279,8 @@ void CGarminTile::readBasics(const QString& fn)
 }
 
 
-static quint32 rgnoff = 0;
-void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFile& file)
+//static quint32 rgnoff = 0;
+void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFileExt &file)
 {
     quint32 i;
     // test for mandatory subfile parts
@@ -483,8 +520,8 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFile& file)
         readFile(file, subfile.parts["TRE"].offset + gar_load(uint32_t, pTreHdr->tre7_offset), gar_load(uint32_t, pTreHdr->tre7_size), subdiv2);
         tre_subdiv2_t * pSubDiv2    = (tre_subdiv2_t*)subdiv2.data();
 
-        const quint32 entries1 = gar_load(uint32_t, pTreHdr->tre7_size) / gar_load(uint32_t, pTreHdr->tre7_rec_size);
-        const quint32 entries2 = subdivs.size();
+        //        const quint32 entries1 = gar_load(uint32_t, pTreHdr->tre7_size) / gar_load(uint32_t, pTreHdr->tre7_rec_size);
+        //        const quint32 entries2 = subdivs.size();
 
         bool skipPois = true;
         if(gar_load(uint32_t, pTreHdr->tre7_rec_size) == sizeof(tre_subdiv2_t)) skipPois = false;
@@ -578,11 +615,11 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFile& file)
         quint32 offsetLbl1 = subfile.parts["LBL"].offset + gar_load(uint32_t, pLblHdr->lbl1_offset);
         quint32 offsetLbl6 = subfile.parts["LBL"].offset + gar_load(uint32_t, pLblHdr->lbl6_offset);
 
+        QByteArray nethdr;
         quint32 offsetNet1  = 0;
         hdr_net_t * pNetHdr = 0;
         if(subfile.parts.contains("NET"))
         {
-            QByteArray nethdr;
             readFile(file, subfile.parts["NET"].offset, sizeof(hdr_net_t), nethdr);
             pNetHdr = (hdr_net_t*)nethdr.data();
             offsetNet1 = subfile.parts["NET"].offset + gar_load(uint32_t, pNetHdr->net1_offset);
@@ -630,14 +667,15 @@ void CGarminTile::readSubfileBasics(subfile_desc_t& subfile, QFile& file)
 
 void CGarminTile::loadVisibleData(bool fast, polytype_t& polygons, polytype_t& polylines, pointtype_t& points, pointtype_t& pois, unsigned level, const QRectF& viewport)
 {
-    QFile file(filename);
+    QFileExt file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
         return;
     }
+//    fprintf(stderr, "loadVisibleData(fast:%d, level:%d): %s (%d)\n", fast, level, qPrintable(filename), file.size());
 
-    QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.begin();
-    while(subfile != subfiles.end())
+    QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.constBegin();
+    while(subfile != subfiles.constEnd())
     {
         //         qDebug() << "subfile:" << subfile->area << viewport << subfile->area.intersects(viewport);
         if(!subfile->area.intersects(viewport))
@@ -653,8 +691,8 @@ void CGarminTile::loadVisibleData(bool fast, polytype_t& polygons, polytype_t& p
 
         const QVector<subdiv_desc_t>&  subdivs = subfile->subdivs;
         // collect polylines
-        QVector<subdiv_desc_t>::const_iterator subdiv = subdivs.begin();
-        while(subdiv != subdivs.end())
+        QVector<subdiv_desc_t>::const_iterator subdiv = subdivs.constBegin();
+        while(subdiv != subdivs.constEnd())
         {
             //             if(subdiv->level == level) qDebug() << "subdiv:" << subdiv->level << level <<  subdiv->area << viewport << subdiv->area.intersects(viewport);
             if(subdiv->level != level || !subdiv->area.intersects(viewport))
@@ -662,7 +700,7 @@ void CGarminTile::loadVisibleData(bool fast, polytype_t& polygons, polytype_t& p
                 ++subdiv;
                 continue;
             }
-            loadSubDiv(file, *subdiv, subfile->strtbl, rgndata, fast, polylines, polygons, points, pois);
+            loadSubDiv(file, *subdiv, subfile->strtbl, rgndata, fast, viewport, polylines, polygons, points, pois);
 
 #ifdef DEBUG_SHOW_SECTION_BORDERS
             IMap& map = CMapDB::self().getMap();
@@ -684,10 +722,42 @@ void CGarminTile::loadVisibleData(bool fast, polytype_t& polygons, polytype_t& p
 }
 
 
-void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, bool fast, polytype_t& polylines, polytype_t& polygons, pointtype_t& points, pointtype_t& pois)
+static inline bool isCompletlyOutside(const QVector<double> &u, const QVector<double> &v, const QRectF &viewport)
+{
+
+    // this should never happen but who knows...
+    if(u.count() != v.count())
+    {
+        return true;
+    }
+
+    double north =  -90.0 * DEG_TO_RAD;
+    double south =   90.0 * DEG_TO_RAD;
+    double west  =  180.0 * DEG_TO_RAD;
+    double east  = -180.0 * DEG_TO_RAD;
+    for(int i = 0; i < u.count(); ++i)
+    {
+        if(north < v[i]) north = v[i];
+        if(south > v[i]) south = v[i];
+        if(west  > u[i]) west  = u[i];
+        if(east  < u[i]) east  = u[i];
+    }
+
+    QRectF ref(west, north,  east - west, south - north);
+
+    if(viewport.intersects(ref))
+    {
+        return false;
+    }
+
+    return true;
+}
+
+
+void CGarminTile::loadSubDiv(QFileExt &file, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, bool fast, const QRectF& viewport, polytype_t& polylines, polytype_t& polygons, pointtype_t& points, pointtype_t& pois)
 {
     if(subdiv.rgn_start == subdiv.rgn_end && !subdiv.lengthPolygons2 && !subdiv.lengthPolylines2 && !subdiv.lengthPoints2) return;
-
+    //fprintf(stderr, "loadSubDiv\n");
     //     qDebug() << "---------" << file.fileName() << "---------";
 
     const quint8 * pRawData = (quint8*)rgndata.data();
@@ -758,6 +828,8 @@ void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminSt
     const quint8 *  pData;
     const quint8 *  pEnd;
 
+    CGarminPolygon p;
+
     // decode points
     if(subdiv.hasPoints && !fast)
     {
@@ -765,14 +837,22 @@ void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminSt
         pEnd  = pRawData + (oidx ? oidx : opline ? opline : opgon ? opgon : subdiv.rgn_end);
         while(pData < pEnd)
         {
-            points.push_back(CGarminPoint());
-            CGarminPoint& p = points.last();
+            CGarminPoint p;
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData);
+
+            // skip points outside our current viewport
+            if(!viewport.contains(p.lon, p.lat))
+            {
+                continue;
+            }
+
             if(strtbl)
             {
                 p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels)
                     : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
             }
+
+            points.push_back(p);
         }
     }
 
@@ -783,14 +863,22 @@ void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminSt
         pEnd  = pRawData + (opline ? opline : opgon ? opgon : subdiv.rgn_end);
         while(pData < pEnd)
         {
-            pois.push_back(CGarminPoint());
-            CGarminPoint& p = pois.last();
+            CGarminPoint p;
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData);
+
+            // skip points outside our current viewport
+            if(!viewport.contains(p.lon, p.lat))
+            {
+                continue;
+            }
+
             if(strtbl)
             {
                 p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels)
                     : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
             }
+
+            pois.push_back(p);
         }
     }
 
@@ -802,11 +890,15 @@ void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminSt
         pEnd  = pRawData + (opgon ? opgon : subdiv.rgn_end);
         while(pData < pEnd)
         {
-            polylines.push_back(CGarminPolygon());
-
-            CGarminPolygon& p   = polylines.last();
-
+//            CGarminPolygon p;
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
+
+            // skip points outside our current viewport
+            if(isCompletlyOutside(p.u, p.v, viewport))
+            {
+                continue;
+            }
+
             if(strtbl && !p.lbl_in_NET && p.lbl_info && !fast)
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
@@ -815,106 +907,129 @@ void CGarminTile::loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminSt
             {
                 strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
             }
+
+            polylines.push_back(p);
         }
     }
 
     // decode polygons
-    if(subdiv.hasPolygons /*&& !fast*/ && !isTransparent()) {
-    CGarminPolygon::cnt = 0;
-    pData = pRawData + opgon;
-    pEnd  = pRawData + subdiv.rgn_end;
-
-    while(pData < pEnd)
+    if(subdiv.hasPolygons  && !isTransparent())
     {
-        polygons.push_back(CGarminPolygon());
-        CGarminPolygon& p   = polygons.last();
+        CGarminPolygon::cnt = 0;
+        pData = pRawData + opgon;
+        pEnd  = pRawData + subdiv.rgn_end;
 
-        pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
-        if(strtbl && !p.lbl_in_NET && p.lbl_info)
+        while(pData < pEnd)
         {
-            strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
-        }
-        else if(strtbl && p.lbl_in_NET && p.lbl_info)
-        {
-            strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
+//            CGarminPolygon p;
+            pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
+
+            // skip points outside our current viewport
+            if(isCompletlyOutside(p.u, p.v, viewport))
+            {
+                continue;
+            }
+
+            if(strtbl && !p.lbl_in_NET && p.lbl_info)
+            {
+                strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
+            }
+            else if(strtbl && p.lbl_in_NET && p.lbl_info)
+            {
+                strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
+            }
+            polygons.push_back(p);
         }
     }
-}
 
+    //         qDebug() << "--- Subdivision" << subdiv.n << "---";
+    //         qDebug() << "adress:" << hex << subdiv.rgn_start << "- " << subdiv.rgn_end;
+    //         qDebug() << "polyg off: " << hex << subdiv.offsetPolygons2;
+    //         qDebug() << "polyg len: " << hex << subdiv.lengthPolygons2 << dec << subdiv.lengthPolygons2;
+    //         qDebug() << "polyg end: " << hex << subdiv.lengthPolygons2 + subdiv.offsetPolygons2;
+    //         qDebug() << "polyl off: " << hex << subdiv.offsetPolylines2;
+    //         qDebug() << "polyl len: " << hex << subdiv.lengthPolylines2 << dec << subdiv.lengthPolylines2;
+    //         qDebug() << "polyl end: " << hex << subdiv.lengthPolylines2 + subdiv.offsetPolylines2;
+    //         qDebug() << "point off: " << hex << subdiv.offsetPoints2;
+    //         qDebug() << "point len: " << hex << subdiv.lengthPoints2 << dec << subdiv.lengthPoints2;
+    //         qDebug() << "point end: " << hex << subdiv.lengthPoints2 + subdiv.offsetPoints2;
 
-//         qDebug() << "--- Subdivision" << subdiv.n << "---";
-//         qDebug() << "adress:" << hex << subdiv.rgn_start << "- " << subdiv.rgn_end;
-//         qDebug() << "polyg off: " << hex << subdiv.offsetPolygons2;
-//         qDebug() << "polyg len: " << hex << subdiv.lengthPolygons2 << dec << subdiv.lengthPolygons2;
-//         qDebug() << "polyg end: " << hex << subdiv.lengthPolygons2 + subdiv.offsetPolygons2;
-//         qDebug() << "polyl off: " << hex << subdiv.offsetPolylines2;
-//         qDebug() << "polyl len: " << hex << subdiv.lengthPolylines2 << dec << subdiv.lengthPolylines2;
-//         qDebug() << "polyl end: " << hex << subdiv.lengthPolylines2 + subdiv.offsetPolylines2;
-//         qDebug() << "point off: " << hex << subdiv.offsetPoints2;
-//         qDebug() << "point len: " << hex << subdiv.lengthPoints2 << dec << subdiv.lengthPoints2;
-//         qDebug() << "point end: " << hex << subdiv.lengthPoints2 + subdiv.offsetPoints2;
-
-if(subdiv.lengthPolygons2 /*&& !fast*/ && !isTransparent()) {
-pData   = pRawData + subdiv.offsetPolygons2;
-pEnd    = pData + subdiv.lengthPolygons2;
-while(pData < pEnd)
-{
-    polygons.push_back(CGarminPolygon());
-    CGarminPolygon& p   = polygons.last();
-    //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
-    pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
-    if(strtbl && !p.lbl_in_NET && p.lbl_info)
+    if(subdiv.lengthPolygons2  && !isTransparent())
     {
-        strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
-    }
-}
-
-
-}
-
-if(subdiv.lengthPolylines2 && !fast)
-{
-    pData   = pRawData + subdiv.offsetPolylines2;
-    pEnd    = pData + subdiv.lengthPolylines2;
-    while(pData < pEnd)
-    {
-        polylines.push_back(CGarminPolygon());
-        CGarminPolygon& p   = polylines.last();
-        //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
-        pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
-        if(strtbl && !p.lbl_in_NET && p.lbl_info)
+        pData   = pRawData + subdiv.offsetPolygons2;
+        pEnd    = pData + subdiv.lengthPolygons2;
+        while(pData < pEnd)
         {
-            strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
+//            CGarminPolygon p;
+            //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
+            pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
+
+            // skip points outside our current viewport
+            if(isCompletlyOutside(p.u, p.v, viewport))
+            {
+                continue;
+            }
+
+            if(strtbl && !p.lbl_in_NET && p.lbl_info)
+            {
+                strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
+            }
+            polygons.push_back(p);
         }
     }
-}
 
-
-if(subdiv.lengthPoints2 && !fast)
-{
-    pData   = pRawData + subdiv.offsetPoints2;
-    pEnd    = pData + subdiv.lengthPoints2;
-    while(pData < pEnd)
+    if(subdiv.lengthPolylines2 && !fast)
     {
-        pois.push_back(CGarminPoint());
-        CGarminPoint& p   = pois.last();
-        //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
-        pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData, pEnd);
-
-        if(strtbl)
+        pData   = pRawData + subdiv.offsetPolylines2;
+        pEnd    = pData + subdiv.lengthPolylines2;
+        while(pData < pEnd)
         {
-            p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels)
-                : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
+//            CGarminPolygon p;
+            //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
+            pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
+
+            // skip points outside our current viewport
+            if(isCompletlyOutside(p.u, p.v, viewport))
+                continue;
+
+            polylines.push_back(p);
+            if(strtbl && !p.lbl_in_NET && p.lbl_info)
+            {
+                strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
+            }
         }
     }
-}
 
+    if(subdiv.lengthPoints2 && !fast)
+    {
+        pData   = pRawData + subdiv.offsetPoints2;
+        pEnd    = pData + subdiv.lengthPoints2;
+        while(pData < pEnd)
+        {
+            CGarminPoint p;
+            //             qDebug() << "rgn offset:" << hex << (rgnoff + (pData - pRawData));
+            pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData, pEnd);
+
+            // skip points outside our current viewport
+            if(!viewport.contains(p.lon, p.lat))
+                continue;
+
+            pois.push_back(p);
+            if(strtbl)
+            {
+                p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels)
+                    : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
+            }
+        }
+    }
 
 }
 
+
 void CGarminTile::loadPolygonsOfType(polytype_t& polygons, quint16 type, unsigned level)
 {
-    QFile file(filename);
+    //  fprintf(stderr, "Load polygons %s\n", qPrintable(filename));
+    QFileExt file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
         return;
@@ -1037,8 +1152,10 @@ void CGarminTile::loadPolygonsOfType(polytype_t& polygons, quint16 type, unsigne
 }
 
 
+#ifdef SQL_SEARCH_GARMIN
 void CGarminTile::createIndex(QSqlDatabase& db)
 {
+    //  fprintf(stderr, "createIndex %s\n", qPrintable(filename));
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
@@ -1279,6 +1396,7 @@ void CGarminTile::createIndexSubDiv(QFile& file, quint32 idSubfile, const subdiv
 
 void CGarminTile::readPolyline(const QString& subfile, quint32 n, quint32 offset, polytype_t& polylines)
 {
+    //  fprintf(stderr, "readPolyline %s\n", qPrintable(filename));
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
@@ -1301,6 +1419,7 @@ void CGarminTile::readPolyline(const QString& subfile, quint32 n, quint32 offset
 
 void CGarminTile::readPoint(const QString& subfile, quint32 n, quint32 offset, pointtype_t& point)
 {
+    //  fprintf(stderr, "readPoint %s\n", qPrintable(filename));
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
@@ -1319,3 +1438,4 @@ void CGarminTile::readPoint(const QString& subfile, quint32 n, quint32 offset, p
 
     file.close();
 }
+#endif                           //SQL_SEARCH_GARMIN
