@@ -43,6 +43,7 @@
 #include "CUndoStack.h"
 #include "WptIcons.h"
 #include "CAppOpts.h"
+#include "CMap3D.h"
 
 #include <QtGui>
 #ifdef WIN32
@@ -116,7 +117,6 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MapMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::MapMenu, "aCenterMap");
-    //    fsMap[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::MapMenu, "aSelectArea");
     actionGroupProvider->addAction(CMenus::MapMenu, "aEditMap");
     actionGroupProvider->addAction(CMenus::MapMenu, "aSearchMap");
@@ -125,37 +125,23 @@ CMainWindow::CMainWindow()
 #endif
     actionGroupProvider->addAction(CMenus::MapMenu, "aUploadMap");
 
-    //     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomIn");
-    //     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomOut");
-    //    fsMap[10] = func_key_state_t(0,tr("-"),0,tr(""));
-
 #ifdef PLOT_3D
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aCloseMap3D");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DMode");
-    actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DZoomPlus");
-    actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DZoomMinus");
+    actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DFPVMode");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DLighting");
-    //actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DTrackmode");
-    //    fsMap3D[5] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMap3D[6] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMap3D[7] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMap3D[8] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMap3D[9] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMap3D[10] = func_key_state_t(0,tr("-"),0,tr(""));
+    actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DTrackMode");
 #endif
 
     actionGroupProvider->addAction(CMenus::WptMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::WptMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::WptMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::WptMenu, "aCenterMap");
-    //    fsWpt[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::WptMenu, "aNewWpt");
     actionGroupProvider->addAction(CMenus::WptMenu, "aEditWpt");
     actionGroupProvider->addAction(CMenus::WptMenu, "aMoveWpt");
 #ifdef HAS_EXIF
     actionGroupProvider->addAction(CMenus::WptMenu, "aImageWpt");
-#else
-    //   fsWpt[8] = func_key_state_t(0, tr("-"), 0, tr(""));
 #endif
     actionGroupProvider->addAction(CMenus::WptMenu, "aUploadWpt");
     actionGroupProvider->addAction(CMenus::WptMenu, "aDownloadWpt");
@@ -164,7 +150,6 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::TrackMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aCenterMap");
-    //    fsTrack[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::TrackMenu, "aCombineTrack");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aEditTrack");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aCutTrack");
@@ -173,44 +158,30 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::TrackMenu, "aDownloadTrack");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aCopyToClipboard");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aPasteFromClipboard");
-    //actionGroupProvider->addAction(CMenus::TrackMenu, "aTrackPurgeSelection");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aDeleteTrackSelection");
 
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aCenterMap");
-    //    fsLiveLog[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aLiveLog");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aLockMap");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aAddWpt");
-    //    fsLiveLog[8] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsLiveLog[9] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsLiveLog[10] = func_key_state_t(0,tr("-"),0,tr(""));
 
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aCenterMap");
-    //    fsOverlay[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aText");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aTextBox");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aDistance");
-    //    fsOverlay[8] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsOverlay[9] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsOverlay[10] = func_key_state_t(0,tr("-"),0,tr(""));
 
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aZoomArea");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aCenterMap");
-    //    fsMainMore[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aDiary");
-    //     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aColorPicker");
-    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aWorldBasemap");
-    //    fsMainMore[8] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMainMore[9] = func_key_state_t(0,tr("-"),0,tr(""));
-    //    fsMainMore[10] = func_key_state_t(0,tr("-"),0,tr(""));
+    //    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aWorldBasemap");
 
     actionGroupProvider->addAction(CMenus::RouteMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aMoveArea");
@@ -348,6 +319,9 @@ CMainWindow::CMainWindow()
         loadData(arg, QString());
     }
 
+    modified = false;
+    setTitleBar();
+
     setupMenuBar();
     connect(actionGroupProvider, SIGNAL(stateChanged()), this, SLOT(switchState()));
 
@@ -374,12 +348,8 @@ void CMainWindow::slotReloadArgs()
         return;
     }
 
-    //    CMapDB::self().clear();
     CWptDB::self().clear();
     CTrackDB::self().clear();
-    //    CRouteDB::self().clear();
-    //    CDiaryDB::self().clear();
-    //    COverlayDB::self().clear();
 
     foreach(QString arg, qlOpts->arguments)
     {
@@ -531,17 +501,6 @@ void CMainWindow::setupMenuBar()
     menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr_nomac("Exit"),this,SLOT(close()));
     menuBar()->addMenu(menu);
 
-    //    groupProvidedMenu = new QMenu(this);
-    //    groupProvidedMenu->setTitle(tr("-"));
-    //    menuBar()->addMenu(groupProvidedMenu);
-
-    // disable for release
-    //    menu = new QMenu(this);
-    //    menu->addAction(CUndoStack::getInstance()->createUndoAction(this));
-    //    menu->addAction(CUndoStack::getInstance()->createRedoAction(this));
-    //    menu->setTitle(tr("&Edit"));
-    //    menuBar()->addMenu(menu);
-
     menu = new QMenu(this);
     actionGroupProvider->addActionsToMenu(menu,CMenus::MenuBarMenu,CMenus::MapMenu);
     menu->setTitle(tr("&Map"));
@@ -593,32 +552,6 @@ void CMainWindow::setupMenuBar()
 }
 
 
-void CMainWindow::keyPressEvent(QKeyEvent * e)
-{
-    /*
-        if((e->key() >= Qt::Key_F1) && (e->key() < Qt::Key_F11)) {
-            return megaMenu->keyPressEvent(e);
-        }
-        else if(e->key() == Qt::Key_Escape) {
-            return megaMenu->keyPressEvent(e);
-        }
-        else if((e->key() == Qt::Key_Plus) || (e->key() == Qt::Key_Minus)) {
-            return megaMenu->keyPressEvent(e);
-        }
-        else if(e->modifiers() == Qt::AltModifier) {
-            if((e->key() == Qt::Key_Up) || (e->key() == Qt::Key_Down)
-            || (e->key() == Qt::Key_Left) || (e->key() == Qt::Key_Right)) {
-                return megaMenu->keyPressEvent(e);
-            }
-        }
-        else if (e->modifiers() == Qt::ControlModifier)
-          return megaMenu->keyPressEvent(e);
-
-        return e->ignore();
-        */
-}
-
-
 void CMainWindow::closeEvent(QCloseEvent * e)
 {
     if(!modified)
@@ -686,7 +619,7 @@ void CMainWindow::slotConfig()
 void CMainWindow::slotLoadData()
 {
 
-    bool haveGPSBabel = QProcess::execute("gpsbabel -V") == 0;
+    bool haveGPSBabel = QProcess::execute(GPSBABEL " -V") == 0;
     QString formats;
     if(haveGPSBabel)
     {
@@ -741,7 +674,7 @@ void CMainWindow::slotLoadData()
 
 void CMainWindow::slotAddData()
 {
-    bool haveGPSBabel = QProcess::execute("gpsbabel -V") == 0;
+    bool haveGPSBabel = QProcess::execute(GPSBABEL " -V") == 0;
     QString formats;
     if(haveGPSBabel)
     {
@@ -905,7 +838,7 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
 
 bool CMainWindow::convertData(const QString& inFormat, const QString& inFile, const QString& outFormat, const QString& outFile)
 {
-    QString program = "gpsbabel";
+    QString program = GPSBABEL;
     QStringList arguments;
     arguments << "-i" << inFormat << "-f" << inFile << "-o" << outFormat << "-F" << outFile;
 
@@ -988,7 +921,7 @@ void CMainWindow::slotExportData()
 }
 
 
-void CMainWindow::saveData(const QString& fn, const QString& filter, bool exportFlag)
+void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
 {
     QString filename = fn;
     QString ext = filename.right(4);
@@ -1005,8 +938,6 @@ void CMainWindow::saveData(const QString& fn, const QString& filter, bool export
     }
     else
     {
-        //         filename += ".qlb";
-        //         ext = "QLB";
         if (ext == ".gpx")
         {
             ext = "GPX";
@@ -1057,9 +988,12 @@ void CMainWindow::saveData(const QString& fn, const QString& filter, bool export
     {
         wksFile.clear();
         QMessageBox:: critical(this,tr("Error"), msg, QMessageBox::Cancel, QMessageBox::Cancel);
+        return;
     }
 
     setTitleBar();
+
+    fn = filename;
 }
 
 
@@ -1070,7 +1004,9 @@ void CMainWindow::slotPrint()
     QPrintDialog dialog(&printer, this);
     dialog.setWindowTitle(tr("Print Map"));
     if (dialog.exec() != QDialog::Accepted)
+    {
         return;
+    }
 
     canvas->print(printer);
 }
@@ -1082,14 +1018,14 @@ void CMainWindow::slotSaveImage()
     QString filter;
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
-        ,"Bitmap (*.png *.jpg);;"
+        ,"Bitmap (*.png *.jpg *.jpeg);;"
         ,&filter
         , QFileDialog::DontUseNativeDialog
         );
 
     if(filename.isEmpty()) return;
 
-    CMap3DWidget * map3d = qobject_cast<CMap3DWidget*>(canvasTab->currentWidget());
+    CMap3D * map3d = qobject_cast<CMap3D*>(canvasTab->currentWidget());
 
     if(map3d)
     {
@@ -1247,6 +1183,9 @@ void CMainWindow::slotDeviceChanged()
     comboDevice->addItem(resources->m_devType, "Garmin");
     comboDevice->addItem(tr("NMEA"), "NMEA");
     comboDevice->addItem(tr("Mikrokopter"), "Mikrokopter");
+#ifdef HAS_GPSD
+    comboDevice->addItem(tr("GPSD"), "GPSD");
+#endif
 
     resources->m_devKey = devKey;
     comboDevice->setCurrentIndex(comboDevice->findData(resources->m_devKey));
