@@ -65,7 +65,6 @@ class CMainWindow : public QMainWindow
         CMenus *getActionGroupProvider() { return actionGroupProvider;};
 
     protected:
-        void keyPressEvent(QKeyEvent * e);
         void closeEvent(QCloseEvent * e);
         void dragEnterEvent(QDragEnterEvent *event);
         void dropEvent(QDropEvent *event);
@@ -100,7 +99,7 @@ class CMainWindow : public QMainWindow
         void loadData(QString& filename, const QString& filter);
         void setTitleBar();
         bool maybeSave();
-        void saveData(const QString& filename, const QString& filter, bool exportFlag = false);
+        void saveData(QString& filename, const QString& filter, bool exportFlag = false);
         bool convertData(const QString& inFormat, const QString& inFile, const QString& outFormat, const QString& outFile);
 
         QMenu *setupMenu;
@@ -122,6 +121,7 @@ class CMainWindow : public QMainWindow
 
         /// the map canvas
         CCanvas * canvas;
+
         /// coordinate label
         QLabel * statusCoord;
 
