@@ -43,7 +43,7 @@
 #define GL_CLAMP_TO_EDGE 0x812F
 #endif
 
-void glError()
+static void glError()
 {
     GLenum err = glGetError();
     while (err != GL_NO_ERROR)
@@ -202,6 +202,7 @@ void CMap3DWidget::changeMode()
     slotChanged();
 }
 
+
 void CMap3DWidget::changeTrackmode()
 {
     if(track.isNull())
@@ -214,7 +215,6 @@ void CMap3DWidget::changeTrackmode()
     IMap& dem = CMapDB::self().getDEM();
     CTrack::pt_t trkpt = track->getTrackPoints().first();
 
-
     pt1.u = trkpt.lon * DEG_TO_RAD;
     pt1.v = trkpt.lat * DEG_TO_RAD;
     if (mapEleAct->isChecked())
@@ -239,6 +239,7 @@ void CMap3DWidget::changeTrackmode()
     updateGL();
 }
 
+
 void CMap3DWidget::eleZoomOut()
 {
     eleZoomFactor = eleZoomFactor / 1.2;
@@ -448,7 +449,7 @@ void CMap3DWidget::drawFlatMap()
 }
 
 
-qint16 *CMap3DWidget::getEleRegion(int& xcount, int& ycount)
+bool CMap3DWidget::getEleRegion(QVector<qint16>& eleData, int& xcount, int& ycount)
 {
     double w = mapSize.width();
     double h = mapSize.height();
@@ -461,10 +462,9 @@ qint16 *CMap3DWidget::getEleRegion(int& xcount, int& ycount)
     p2.v = h;
     map->convertPt2Rad(p1.u, p1.v);
     map->convertPt2Rad(p2.u, p2.v);
-    qint16 * eleData;
-    eleData = dem.getOrigRegion(p1, p2, xcount, ycount);
-    //FIXME we must move and resize map accordin to new p1 and p2
-    return eleData;
+
+    return dem.getOrigRegion(eleData.data(), p1, p2, xcount, ycount);
+
 }
 
 
@@ -601,9 +601,10 @@ void CMap3DWidget::draw3DMap()
         ycount = (h / step + 1);
     }
 
-    qint16 *eleData;
-    eleData = getEleRegion(xcount, ycount);
-    if (eleData == NULL)
+    QVector<qint16> eleData(xcount*ycount);
+
+    bool ok = getEleRegion(eleData, xcount, ycount);
+    if (!ok)
     {
         qDebug() << "can't get elevation data";
         qDebug() << "draw flat map";
@@ -674,9 +675,9 @@ void CMap3DWidget::draw3DMap()
             b[1] = iy + s;
             c[0] = ix - s;
             c[1] = iy + s;
-            getPopint(a, ix + s, iy + s , ix, iy, xcount, ycount, current_step_x, current_step_y, eleData);
-            getPopint(b, ix - s, iy - s, ix, iy, xcount, ycount, current_step_x, current_step_y, eleData);
-            getPopint(c, ix + s, iy - s, ix, iy, xcount, ycount, current_step_x, current_step_y, eleData);
+            getPopint(a, ix + s, iy + s , ix, iy, xcount, ycount, current_step_x, current_step_y, eleData.data());
+            getPopint(b, ix - s, iy - s, ix, iy, xcount, ycount, current_step_x, current_step_y, eleData.data());
+            getPopint(c, ix + s, iy - s, ix, iy, xcount, ycount, current_step_x, current_step_y, eleData.data());
             getNormal(a, b, c, &normals[iv]);
         }
 
@@ -698,7 +699,6 @@ void CMap3DWidget::draw3DMap()
     delete [] vertices;
     delete [] texCoords;
     delete [] normals;
-    delete [] eleData;
     glDisable(GL_TEXTURE_2D);
     glError();
 }
@@ -716,11 +716,11 @@ void CMap3DWidget::updateElevationLimits()
     int xcount = (w / step + 1);
     int ycount = (h / step + 1);
 
-    qint16 * eleData;
+    QVector<qint16> eleData(xcount*ycount);
 
-    eleData = getEleRegion(xcount, ycount);
+    bool ok = getEleRegion(eleData, xcount, ycount);
     minElevation = maxElevation = 0;
-    if (eleData != NULL)
+    if (ok)
     {
         minElevation = maxElevation = eleData[0];
 
@@ -765,7 +765,7 @@ void CMap3DWidget::updateElevationLimits()
         maxElevation = 1;
         minElevation = 0;
     }
-    delete [] eleData;
+
 }
 
 
@@ -951,6 +951,7 @@ void CMap3DWidget::paintGL()
     glTranslated(0.0, 0.0, -side);
     glRotated(-xRot, 1.0, 0.0, 0.0);
     glScalef(zoomFactor, zoomFactor, zoomFactor);
+
     glTranslated(xShift, yShift, zShift);
 
     glRotated(zRot, 0.0, 0.0, 1.0);
@@ -968,14 +969,13 @@ void CMap3DWidget::paintGL()
         glEnable(GL_LIGHT0);
 
         GLfloat light0_pos[] = {xLight, yLight, - (zLight + minElevation), 0.0};
-        /*
-        GLfloat diffuse0[] = {0.5, 1.0, 1.0, 1.0};
-        GLfloat ambient0[] = {1.0, 0.5, 1.0, 1.0};
-        GLfloat specular0[] = {1.0, 1.0, 0.5, 1.0};
-        glLightfv(GL_LIGHT0, GL_AMBIENT, ambient0);
-        glLightfv(GL_LIGHT0, GL_DIFFUSE, specular0);
-        glLightfv(GL_LIGHT0, GL_SPECULAR, diffuse0);
-        */
+
+        //         GLfloat diffuse0[] = {0.5, 1.0, 1.0, 1.0};
+        //         GLfloat ambient0[] = {1.0, 0.5, 1.0, 1.0};
+        //         GLfloat specular0[] = {1.0, 1.0, 0.5, 1.0};
+        //         glLightfv(GL_LIGHT0, GL_AMBIENT, ambient0);
+        //         glLightfv(GL_LIGHT0, GL_DIFFUSE, specular0);
+        //         glLightfv(GL_LIGHT0, GL_SPECULAR, diffuse0);
 
         glLightfv(GL_LIGHT0, GL_POSITION, light0_pos);
         glShadeModel(GL_SMOOTH);
@@ -1176,7 +1176,7 @@ void CMap3DWidget::resizeGL(int width, int height)
     glLoadIdentity();
     /* 20 is equal to value of a maximum zoom factor. */
     glFrustum(-width/100.0, width/100.0, -height/100.0, height/100.0, side/100.0, 200.0 * side);
-    //glOrtho(-width, width, -height, height, 0, 20 * side);
+    //     glOrtho(-width, width, -height, height, 0, 20 * side);
     glMatrixMode(GL_MODELVIEW);
 }
 
