@@ -31,7 +31,7 @@
 #include "GeoMath.h"
 #include "CCanvas.h"
 #ifdef PLOT_3D
-#include "CMap3DWidget.h"
+#include "CMap3D.h"
 #endif
 #include "CTabWidget.h"
 #include "CMapSelectionGarmin.h"
@@ -137,6 +137,12 @@ CMapDB::~CMapDB()
 }
 
 
+CMap3D * CMapDB::getMap3D()
+{
+    return map3D;
+}
+
+
 void CMapDB::clear()
 {
     selectedMaps.clear();
@@ -275,6 +281,11 @@ void CMapDB::openMap(const QString& filename, bool asRaster, CCanvas& canvas)
     QString fileDEM = cfg.value(QString("map/dem/%1").arg(theMap->getKey()),"").toString();
     if(!fileDEM.isEmpty()) openDEM(fileDEM);
 
+#ifdef PLOT_3D_NEW
+    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+#endif
+
     emit sigChanged();
 
     QApplication::restoreOverrideCursor();
@@ -341,6 +352,11 @@ void CMapDB::openMap(const QString& key)
         theMap->move(QPoint(midU, midV), theMainWindow->getCanvas()->rect().center());
     }
 
+#ifdef PLOT_3D_NEW
+    CMap3D * map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+    theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
+#endif
+
     emit sigChanged();
     QApplication::restoreOverrideCursor();
 }
@@ -534,14 +550,14 @@ void CMapDB::editMap()
 #ifdef PLOT_3D
 void CMapDB::show3DMap(bool show)
 {
-    if(map3DWidget.isNull() && show)
+    if(map3D.isNull() && show)
     {
-        map3DWidget = new CMap3DWidget(theMainWindow->getCanvas());
-        theMainWindow->getCanvasTab()->addTab(map3DWidget, tr("Map 3D..."));
+        map3D = new CMap3D(theMap, theMainWindow->getCanvas());
+        theMainWindow->getCanvasTab()->addTab(map3D, tr("Map 3D..."));
     }
-    else if(!map3DWidget.isNull() && !show)
+    else if(!map3D.isNull() && !show)
     {
-        map3DWidget->deleteLater();
+        map3D->deleteLater();
     }
 }
 #endif
