@@ -21,7 +21,10 @@
 #include "CCreateMapOSM.h"
 #include "CCreateMapQMAP.h"
 #include "CCreateMapGeoTiff.h"
+#include "CCreateMapFineTune.h"
+#ifdef WMS_CLIENT
 #include "CCreateMapWMS.h"
+#endif
 
 #include <QtGui>
 
@@ -34,8 +37,8 @@ CMapEditWidget::CMapEditWidget(QWidget * parent)
     toolExit->setIcon(QIcon(":/icons/iconExit16x16.png"));
     connect(toolExit, SIGNAL(clicked()), this, SLOT(close()));
 
-    bool haveGDALWarp       = QProcess::execute("gdalwarp --version") == 0;
-    bool haveGDALTranslate  = QProcess::execute("gdal_translate --version") == 0;
+    bool haveGDALWarp       = QProcess::execute(GDALWARP " --version") == 0;
+    bool haveGDALTranslate  = QProcess::execute(GDALTRANSLATE " --version") == 0;
     bool haveGDAL = haveGDALWarp && haveGDALTranslate;
 
     comboSource->insertItem(eNone,tr(""));
@@ -53,6 +56,7 @@ CMapEditWidget::CMapEditWidget(QWidget * parent)
     {
         widgetGeoTiff   = new CCreateMapGeoTiff(stackedWidget);
         stackedWidget->insertWidget(eGTIFF, widgetGeoTiff);
+
     }
     else
     {
@@ -62,10 +66,16 @@ CMapEditWidget::CMapEditWidget(QWidget * parent)
         stackedWidget->insertWidget(eGTIFF, label);
     }
 
+    comboSource->insertItem(eFineTune,QIcon(":/icons/iconGlobe16x16.png"),tr("Fine tune offset of referenced file."));
+    widgetFineTune  = new CCreateMapFineTune(stackedWidget);
+    stackedWidget->insertWidget(eFineTune, widgetFineTune);
+
+
+#ifdef WMS_CLIENT
     comboSource->insertItem(eWMS,QIcon(":/icons/iconWMS16x16.png"),tr("Create a GDAL WMS definition file."));
     widgetWMS       = new CCreateMapWMS(stackedWidget);
     stackedWidget->insertWidget(eWMS, widgetWMS);
-
+#endif
     connect(comboSource, SIGNAL(activated(int)), stackedWidget, SLOT(setCurrentIndex(int)));
 }
 
