@@ -38,10 +38,10 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
 , yref1(0)
 , xref2(0)
 , yref2(0)
-, lon1(0)
-, lat1(0)
-, lon2(0)
-, lat2(0)
+//, lon1(0)
+//, lat1(0)
+//, lon2(0)
+//, lat2(0)
 , x(0)
 , y(0)
 , zoomFactor(1.0)
@@ -50,7 +50,7 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
 {
     filename = fn;
 
-    dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_ReadOnly);
+    dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_Update);
     if(dataset == 0)
     {
         QMessageBox::warning(0, tr("Error..."), tr("Failed to load file: %1").arg(filename));
@@ -150,13 +150,13 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     xref2   = xref1 + xsize_px * xscale;
     yref2   = yref1 + ysize_px * yscale;
 
-    lon1 = xref1;
-    lat1 = yref1;
-    pj_transform(pjsrc,pjtar,1,0,&lon1,&lat1,0);
-
-    lon2 = xref2;
-    lat2 = yref2;
-    pj_transform(pjsrc,pjtar,1,0,&lon2,&lat2,0);
+//    lon1 = xref1;
+//    lat1 = yref1;
+//    pj_transform(pjsrc,pjtar,1,0,&lon1,&lat1,0);
+//
+//    lon2 = xref2;
+//    lat2 = yref2;
+//    pj_transform(pjsrc,pjtar,1,0,&lon2,&lat2,0);
 
     x = xref1 + (xref2 - xref1) / 2;
     y = yref1 - (yref1 - yref2) / 2;
@@ -212,6 +212,14 @@ void CMapGeoTiff::draw(QPainter& p)
 
     p.drawImage(0,0,buffer);
 
+    // render overlay
+    if(!ovlMap.isNull() && !doFastDraw)
+    {
+        qDebug() << size << needsRedraw;
+        ovlMap->draw(size, needsRedraw, p);
+    }
+
+
     p.setPen(Qt::white);
     p.setFont(QFont("Sans Serif",14,QFont::Black));
 
@@ -361,6 +369,8 @@ void CMapGeoTiff::move(const QPoint& old, const QPoint& next)
     x = xx;
     y = yy;
     emit sigChanged();
+
+    setAngleNorth();
 }
 
 
@@ -450,8 +460,8 @@ void CMapGeoTiff::zoom(double lon1, double lat1, double lon2, double lat2)
     dU = (u[1] - u[0]) / xscale;
     dV = (v[0] - v[2]) / yscale;
 
-    int z1 = dU / size.width();
-    int z2 = dV / size.height();
+    int z1 = fabs(dU / size.width());
+    int z2 = fabs(dV / size.height());
 
     zoomFactor = (z1 > z2 ? z1 : z2)  + 1;
     if(quadraticZoom->isChecked())
@@ -481,8 +491,70 @@ void CMapGeoTiff::select(const QRect& rect)
 
 void CMapGeoTiff::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 {
-    lon1 = this->lon1;
-    lat1 = this->lat1;
-    lon2 = this->lon2;
-    lat2 = this->lat2;
+
+    lon1 = xref1;
+    lat1 = yref1;
+    pj_transform(pjsrc,pjtar,1,0,&lon1,&lat1,0);
+
+    lon2 = xref2;
+    lat2 = yref2;
+    pj_transform(pjsrc,pjtar,1,0,&lon2,&lat2,0);
+}
+
+void CMapGeoTiff::incXOffset(int i)
+{
+    xref1 += i * xscale;
+    xref2 += i * xscale;
+
+    emit sigChanged();
+}
+
+void CMapGeoTiff::decXOffset(int i)
+{
+    xref1 -= i * xscale;
+    xref2 -= i * xscale;
+
+    emit sigChanged();
+}
+
+void CMapGeoTiff::incYOffset(int i)
+{
+    yref1 -= i * yscale;
+    yref2 -= i * yscale;
+
+    emit sigChanged();
+}
+
+void CMapGeoTiff::decYOffset(int i)
+{
+    yref1 += i * yscale;
+    yref2 += i * yscale;
+
+    emit sigChanged();
+}
+
+GDALDataset * CMapGeoTiff::getDataset()
+{
+    return dataset;
+}
+
+void CMapGeoTiff::getArea_n_Scaling(XY& p1, XY& p2, float& my_xscale, float& my_yscale)
+{
+
+    p1.u = x;
+    p1.v = y;
+    convertM2Rad(p1.u, p1.v);
+
+    p2.u = x;
+    p2.v = y;
+    convertM2Pt(p2.u, p2.v);
+
+    p2.u += xsize_px;
+    p2.v += ysize_px;
+
+    convertPt2Rad(p2.u, p2.v);
+
+
+    my_xscale   = xscale*zoomFactor;
+    my_yscale   = yscale*zoomFactor;
 }
