@@ -28,21 +28,27 @@
 
 CMapOSM::CMapOSM(CCanvas * parent)
 : IMap(eTile, "OSMTileServer", parent)
-, xscale( 1.19432854652)
-, yscale(-1.19432854652)
+, parent(parent)
+, zoomFactor(1.0)
 , x(0)
 , y(0)
-, zoomFactor(1.0)
+, xscale( 1.19432854652)
+, yscale(-1.19432854652)
 , needsRedrawOvl(true)
-, parent(parent)
+
 {
     currentTileListIndex = -1;
     osmTiles = 0;
     // %1 = osm_zoom; %2 = osm_x; %3 = osm_y
     tileList << qMakePair(QString("OpenStreetMap"),QString("tile.openstreetmap.org/%1/%2/%3.png"));
-    tileList << qMakePair(QString("cloudmade.com (cycle)"),QString("andy.sandbox.cloudmade.com/tiles/cycle/%1/%2/%3.png"));
-    tileList << qMakePair(QString("topo.geofabrik.de (trails)"),QString("topo.geofabrik.de/trails/%1/%2/%3.png"));
+    tileList << qMakePair(QString("OpenCycleMap"),QString("andy.sandbox.cloudmade.com/tiles/cycle/%1/%2/%3.png"));
+    //    tileList << qMakePair(QString("topo.geofabrik.de CC-NC-SA"),QString("topo.geofabrik.de/trails/%1/%2/%3.png"));
     tileList << qMakePair(QString("OpenPisteMap"),QString("openpistemap.org/tiles/contours/%1/%2/%3.png"));
+#if PRIVATE
+    tileList << qMakePair(QString("Outdooractive DE"),QString("t0.outdooractive.com/portal/map/%1/%2/%3.png"));
+    tileList << qMakePair(QString("Outdooractive AU"),QString("t0.outdooractive.com/austria/map/%1/%2/%3.png"));
+    tileList << qMakePair(QString("Outdooractive IT"),QString("t0.outdooractive.com/suedtirol/map/%1/%2/%3.png"));
+#endif
 
     cb = new QComboBox(theMainWindow->getCanvas());
 
@@ -69,8 +75,8 @@ CMapOSM::CMapOSM(CCanvas * parent)
     qDebug() << "OSM:" << ptr;
     //     if(ptr) free(ptr);
 
-    QString pos     = cfg.value("osm/topleft","").toString();
-    zoomidx         = cfg.value("osm/zoomidx",1).toInt();
+    QString pos     = cfg.value("osm/topleft","N82 58.759 W151 08.934").toString();
+    zoomidx         = cfg.value("osm/zoomidx",15).toInt();
 
     lon1 = xref1   = -40075016/2;
     lat1 = yref1   =  40075016/2;
@@ -128,11 +134,15 @@ CMapOSM::~CMapOSM()
 
 void CMapOSM::setNewTileUrl(int index)
 {
-    if (index == -1)
-        if (currentTileListIndex < tileList.size() -1 )
-            index = currentTileListIndex+1;
-    else
+
+    if(index >= tileList.count())
+    {
+        index = tileList.count() - 1;
+    }
+    else if(index < 0)
+    {
         index = 0;
+    }
 
     if (currentTileListIndex!= index)
     {
@@ -151,6 +161,7 @@ void CMapOSM::setNewTileUrl(int index)
         needsRedraw = true;
         emit sigChanged();
     }
+
 }
 
 
@@ -182,8 +193,10 @@ void CMapOSM::move(const QPoint& old, const QPoint& next)
     y = yy;
     needsRedraw     = true;
     needsRedrawOvl  = true;
-    setFastDraw();
+    setFastDrawTimer();
     emit sigChanged();
+
+    setAngleNorth();
 }
 
 
@@ -238,7 +251,7 @@ void CMapOSM::zoom(qint32& level)
     zoomFactor = (1<<(level-1));
     needsRedraw     = true;
     needsRedrawOvl   = true;
-    setFastDraw();
+    setFastDrawTimer();
     emit sigChanged();
 
 }
@@ -259,8 +272,8 @@ void CMapOSM::zoom(double lon1, double lat1, double lon2, double lat2)
     v[2] = lat2;
 
     pj_transform(pjtar, pjsrc,3,0,u,v,0);
-    dU = u[1] - u[0];
-    dV = v[0] - v[2];
+    dU = fabs(u[1] - u[0]);
+    dV = fabs(v[0] - v[2]);
 
     int z1 = dU / size.width();
     int z2 = dV / size.height();
@@ -272,6 +285,8 @@ void CMapOSM::zoom(double lon1, double lat1, double lon2, double lat2)
         if(zoomFactor > z1 && zoomFactor > z2) break;
     }
 
+    qDebug() << zoomFactor << z1 << zoomFactor << z2;
+
     double u_ = lon1 + (lon2 - lon1)/2;
     double v_ = lat1 + (lat2 - lat1)/2;
     convertRad2Pt(u_,v_);
@@ -333,8 +348,12 @@ void CMapOSM::draw(QPainter& p)
 
     p.setFont(QFont("Sans Serif",8,QFont::Black));
 
-    CCanvas::drawText(tr("Map has been created by %1 under Creative Commons Attribution-ShareAlike 2.0 license").arg(tileList.at(currentTileListIndex).first), p, rect.bottomLeft() + QPoint(rect.width() / 2, -5) , QColor(Qt::darkBlue));
-    CCanvas::drawText(tr("and has been downloaded from: %1").arg(QString(tileList.at(currentTileListIndex).second).arg('z').arg('x').arg('y')), p, rect.bottomLeft() + QPoint(rect.width() / 2, +7) , QColor(Qt::darkBlue));
+    if(currentTileListIndex < 3)
+    {
+        CCanvas::drawText(tr("Map has been created by %1 under Creative Commons Attribution-ShareAlike 2.0 license").arg(tileList.at(currentTileListIndex).first), p, rect.bottomLeft() + QPoint(rect.width() / 2, -5) , QColor(Qt::darkBlue));
+        CCanvas::drawText(tr("and has been downloaded from: %1").arg(QString(tileList.at(currentTileListIndex).second).arg('z').arg('x').arg('y')), p, rect.bottomLeft() + QPoint(rect.width() / 2, +7) , QColor(Qt::darkBlue));
+    }
+
 
 }
 
