@@ -222,7 +222,7 @@ void CMapQMAP::__test()
     convertPt2Rad(p2.u, p2.v);
 
     QVector<float> ele2(c * r);
-    dem.getRegion(ele2.data(), p1, p2, c, r);
+    dem.getRegion(ele2, p1, p2, c, r);
 
     printf("---------------------\n");
 
@@ -372,7 +372,7 @@ void CMapQMAP::draw()
         ++mapfile;
     }
 
-    if(doFastDraw) setFastDraw();
+    if(doFastDraw) setFastDrawTimer();
 }
 
 
@@ -419,8 +419,10 @@ void CMapQMAP::move(const QPoint& old, const QPoint& next)
     topLeft = p2;
 
     needsRedraw = true;
-    setFastDraw();
+    setFastDrawTimer();
     emit sigChanged();
+
+    setAngleNorth();
 }
 
 
@@ -498,7 +500,7 @@ void CMapQMAP::zoom(qint32& level)
     if(level < 1)
     {
         zoomFactor  = 1.0 / - (level - 2);
-        setFastDraw();
+        setFastDrawTimer();
         emit sigChanged();
         qDebug() << "zoom:" << zoomFactor;
         return;
@@ -527,7 +529,7 @@ void CMapQMAP::zoom(qint32& level)
     pMaplevel   = *maplevel;
     pjsrc       = (*pMaplevel->begin())->pj;
     zoomFactor  = level - (*maplevel)->min + 1;
-    setFastDraw();
+    setFastDrawTimer();
     emit sigChanged();
     qDebug() << "zoom:" << zoomFactor;
 }
@@ -567,9 +569,10 @@ void CMapQMAP::zoom(double lon1, double lat1, double lon2, double lat2)
         for(level = (*maplevel)->min; level <= (*maplevel)->max; ++level)
         {
             int z = level - (*maplevel)->min + 1;
-            double pxU = dU / (map->xscale * z);
-            double pxV = dV / (map->yscale * z);
+            double pxU = fabs(dU / (map->xscale * z));
+            double pxV = fabs(dV / (map->yscale * z));
 
+            qDebug() << pxU << size.width() << pxV << size.height();
             if((pxU < size.width()) && (pxV < size.height()))
             {
                 pMaplevel   = *maplevel;
