@@ -29,7 +29,9 @@
 #include "CImage.h"
 #include "CMapSearchThread.h"
 #include "IMap.h"
+#ifdef SQL_SEARCH_GARMIN
 #include "CGarminIndex.h"
+#endif                           //SQL_SEARCH_GARMIN
 #include "config.h"
 
 #include <QtGui>
@@ -64,9 +66,7 @@ CMapSearchWidget::CMapSearchWidget(QWidget * parent)
     mask = new CImage(this);
     loadMaskCollection();
 
-    connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotMapChanged()));
-    slotMapChanged();
-
+#ifdef SQL_SEARCH_GARMIN
     connect(pushCreateIndex, SIGNAL(clicked()), this, SLOT(slotCreateIndex()));
     connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotIndexChanged()));
     slotIndexChanged();
@@ -84,6 +84,12 @@ CMapSearchWidget::CMapSearchWidget(QWidget * parent)
     connect(lineTextToFindPoints, SIGNAL( textChanged(const QString &)), SLOT(slotPointSearchChanged( const QString& )));
     connect(lineTextToFindPoints, SIGNAL( returnPressed()), SLOT(slotPointSearchChanged()));
     connect(listResultPoints, SIGNAL(itemSelectionChanged ()), this, SLOT(slotPointSelected()));
+#else
+    tabWidget->removeTab(0);
+#endif                       //SQL_SEARCH_GARMIN
+
+    connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotMapChanged()));
+    slotMapChanged();
 
     QSettings cfg;
     checkSearchViewport->setChecked(cfg.value("search/viewportlimit", false).toBool());
@@ -104,11 +110,13 @@ CMapSearchWidget::~CMapSearchWidget()
     while(map && map->maptype != IMap::eGarmin) map = map->getOverlay();
     if(map == 0) return;
 
+#ifdef SQL_SEARCH_GARMIN
     CMapTDB * tdb = qobject_cast<CMapTDB *>(map);
     QVector<CGarminPoint>   res1;
     QVector<CGarminPolygon> res2;
     tdb->highlight(res1);
     tdb->highlight(res2);
+#endif                       //SQL_SEARCH_GARMIN
 }
 
 
@@ -157,8 +165,8 @@ void CMapSearchWidget::slotCancel()
 
 void CMapSearchWidget::slotSearchFinished()
 {
-    QPoint symbol;
-    const QList<QPoint>& symbols = thread->getLastResult();
+    QPointF symbol;
+    const QList<QPointF>& symbols = thread->getLastResult();
 
     IMap& map = CMapDB::self().getMap();
 
@@ -170,7 +178,11 @@ void CMapSearchWidget::slotSearchFinished()
         double u = symbol.x();
         double v = symbol.y();
 
-        map.convertM2Rad(u,v);
+        if((u > PI/2) || (v > PI/4))
+        {
+            map.convertM2Rad(u,v);
+        }
+
         CSearchDB::self().add(tr("%2 %1").arg(++cnt).arg(name), u, v);
     }
 
@@ -229,6 +241,7 @@ void CMapSearchWidget::slotSaveMask()
     file.open(QIODevice::WriteOnly);
 
     QDataStream out(&file);
+    out.setVersion(QDataStream::Qt_4_5);
     out << sliderThreshold->value();
     out << (int)1;
     out << mask->rgb();
@@ -250,6 +263,7 @@ void CMapSearchWidget::slotSelectMaskByName(const QString& name)
     if(file.open(QIODevice::ReadOnly))
     {
         QDataStream in(&file);
+        in.setVersion(QDataStream::Qt_4_5);
 
         in >> intval;
         sliderThreshold->setValue(intval);
@@ -315,6 +329,7 @@ void CMapSearchWidget::loadMaskCollection()
         QFile file(path.filePath(maskfile));
         file.open(QIODevice::ReadOnly);
         QDataStream in(&file);
+        in.setVersion(QDataStream::Qt_4_5);
         in >> intval;
         in >> intval;
         in >> pixmap;
@@ -367,13 +382,20 @@ void CMapSearchWidget::checkGui()
 void CMapSearchWidget::slotMapChanged()
 {
     IMap& map  = CMapDB::self().getMap();
+#ifdef SQL_SEARCH_GARMIN
     IMap * ovl = map.getOverlay();
+#endif                       //SQL_SEARCH_GARMIN
 
+#ifdef SQL_SEARCH_GARMIN
     tabWidget->widget(1)->setEnabled(map.maptype == IMap::eRaster || map.maptype == IMap::eTile);
     tabWidget->widget(0)->setEnabled(map.maptype == IMap::eGarmin || (ovl && (ovl->maptype == IMap::eGarmin)));
+#else
+    tabWidget->widget(0)->setEnabled(map.maptype == IMap::eRaster || map.maptype == IMap::eTile);
+#endif                       //SQL_SEARCH_GARMIN
 }
 
 
+#ifdef SQL_SEARCH_GARMIN
 void CMapSearchWidget::slotProgressIndex(const QString& status, const int progress)
 {
     labelProgress2->setText(status);
@@ -626,3 +648,4 @@ void CMapSearchWidget::slotPointSelected()
 
     QApplication::restoreOverrideCursor();
 }
+#endif                           //SQL_SEARCH_GARMIN
