@@ -28,10 +28,14 @@
 #include <QFont>
 #include <QFontMetrics>
 
-class CGarminTile;
+
 class QTimer;
 class QTextDocument;
+
+#ifdef SQL_SEARCH_GARMIN
 class CGarminIndex;
+#endif                           //SQL_SEARCH_GARMIN
+
 class QCheckBox;
 class QComboBox;
 
@@ -59,11 +63,13 @@ class CMapTDB : public IMap
         void registerDEM(CMapDEM& dem);
         void select(IMapSelection& ms, const QRect& rect);
 
+#ifdef SQL_SEARCH_GARMIN
         void createSearchIndex(QObject * reveiver, const char * slot);
         CGarminIndex * getSearchIndex(){return index;}
 
         void highlight(QVector<CGarminPolygon>& res);
         void highlight(QVector<CGarminPoint>& res);
+#endif                       //SQL_SEARCH_GARMIN
 
         void config();
     protected:
@@ -76,10 +82,12 @@ class CMapTDB : public IMap
         void slotNightView(bool checked);
         void slotDetailChanged(int idx);
         void slotLanguageChanged(int idx);
+        void slotTypfileChanged(int idx);
 
     private:
         friend class CDlgMapTDBConfig;
         void setup();
+        void checkTypFiles();
 
         struct strlbl_t
         {
@@ -103,19 +111,19 @@ class CMapTDB : public IMap
         bool processPrimaryMapData();
         void drawPolylines(QPainter& p, polytype_t& lines);
         void drawPolygons(QPainter& p, polytype_t& lines);
-        void drawPoints(QPainter& p, pointtype_t& points);
-        void drawPois(QPainter& p, pointtype_t& points);
-        void drawLabels(QPainter& p, QVector<strlbl_t> lbls);
+        void drawPoints(QPainter& p, pointtype_t& points, QVector<QRect>& rectPois);
+        void drawPois(QPainter& p, pointtype_t& points, QVector<QRect>& rectPois);
+        void drawLabels(QPainter& p, const QVector<strlbl_t> &lbls);
         void drawText(QPainter& p);
 
         void getInfoPoints(const QPoint& pt, QMultiMap<QString, QString>& dict);
         void getInfoPois(const QPoint& pt, QMultiMap<QString, QString>& dict);
         void getInfoPolygons(const QPoint& pt, QMultiMap<QString, QString>& dict);
         void getInfoPolylines(QPoint& pt, QMultiMap<QString, QString>& dict);
-        void collectText(CGarminPolygon& item, QPolygonF& line, QFont& font, QFontMetricsF metrics, qint32 lineWidth);
+        void collectText(const CGarminPolygon& item, const QPolygonF& line, const QFont& font, const QFontMetricsF& metrics, qint32 lineWidth);
 
-        void drawLine(QPainter& p, CGarminPolygon& l, IGarminTyp::polyline_property& property, QFontMetricsF& metrics, QFont& font);
-        void drawLine(QPainter& p, CGarminPolygon& l);
+        void drawLine(QPainter& p, CGarminPolygon& l, const IGarminTyp::polyline_property& property, const QFontMetricsF& metrics, const QFont& font);
+        void drawLine(QPainter& p, const CGarminPolygon& l);
 
 #pragma pack(1)
         struct tdb_hdr_t
@@ -169,7 +177,7 @@ class CMapTDB : public IMap
 
         struct tile_t
         {
-            tile_t() : selected(false){}
+            tile_t() : img(0), selected(false){}
             quint32 id;
             QString key;
             QString name;
@@ -222,6 +230,10 @@ class CMapTDB : public IMap
             quint32 bits;
         };
 
+        void readTile(tile_t& tile);
+
+        bool tainted;
+
         /// tdb filename
         QString filename;
         /// typ filename
@@ -288,16 +300,19 @@ class CMapTDB : public IMap
 
         struct textpath_t
         {
-            QPainterPath    path;
+//            QPainterPath    path;
+            QPolygonF       polyline;
             QString         text;
             QFont           font;
             QVector<qreal>  lengths;
-            qint32          lineWidth;
+            qint32          lineWidth;            
         };
 
         QVector<textpath_t> textpaths;
 
+#ifdef SQL_SEARCH_GARMIN
         CGarminIndex * index;
+#endif                       //SQL_SEARCH_GARMIN
 
         QVector<CGarminPolygon> query1;
         QVector<CGarminPoint> query2;
@@ -321,5 +336,9 @@ class CMapTDB : public IMap
 
         quint8 selectedLanguage;
 
+        QPixmap pixBuffer;
+
+        QComboBox * comboTypfiles;
+
 };
 #endif                           //CMAPTDB_H
