@@ -245,9 +245,9 @@ void CMapToolWidget::slotContextMenuKnownMaps(const QPoint& pos)
         {
             actAddDEM->setEnabled(true);
             actDelDEM->setEnabled(dem.maptype == IMap::eDEM);
-            actDelMap->setEnabled(false);
             int mapType = item->data(eType, Qt::UserRole).toInt();
-            if(mapType == IMap::eGarmin || mapType == IMap::eTile)
+//            if(mapType == IMap::eGarmin || mapType == IMap::eTile)
+            if(0)
             {
                 actCfgMap->setEnabled(true);
             }
@@ -260,7 +260,6 @@ void CMapToolWidget::slotContextMenuKnownMaps(const QPoint& pos)
         {
             actAddDEM->setEnabled(false);
             actDelDEM->setEnabled(false);
-            actDelMap->setEnabled(true);
             actCfgMap->setEnabled(false);
         }
 
@@ -284,18 +283,29 @@ void CMapToolWidget::slotDeleteKnownMap()
 {
     QStringList keys;
     QTreeWidgetItem * item;
-    QTreeWidget * treeWidget = dynamic_cast<QTreeWidget*>(sender());
+    //    QTreeWidget * treeWidget = dynamic_cast<QTreeWidget*>(sender());
+
+    bool wasSelected = false;
 
     if(lastTreeWidget)
     {
         const QList<QTreeWidgetItem*>& items = lastTreeWidget->selectedItems();
         foreach(item,items)
         {
+            if(item->data(eMode, Qt::UserRole).toInt() == eSelected)
+            {
+                wasSelected = true;
+            }
             keys << item->data(eName, Qt::UserRole).toString();
             delete item;
         }
         CMapDB::self().delKnownMap(keys);
     }
+
+    if(wasSelected)
+    {
+        CMapDB::self().openMap("NoMap");
+    }
 }
 
 
@@ -347,8 +357,8 @@ void CMapToolWidget::slotExportMap()
     const IMapSelection * ms = selectedMaps[key];
     if(ms->type == IMapSelection::eRaster)
     {
-        bool haveGDALWarp       = QProcess::execute("gdalwarp --version") == 0;
-        bool haveGDALTranslate  = QProcess::execute("gdal_translate --version") == 0;
+        bool haveGDALWarp       = QProcess::execute(GDALWARP " --version") == 0;
+        bool haveGDALTranslate  = QProcess::execute(GDALTRANSLATE " --version") == 0;
         bool haveGDAL = haveGDALWarp && haveGDALTranslate;
         if(!haveGDAL)
         {
@@ -372,7 +382,7 @@ void CMapToolWidget::slotAddDEM()
     QSettings cfg;
     path = QDir(cfg.value("path/DEM",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit GeoTiff (*.tif)"), 0, QFileDialog::DontUseNativeDialog);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit Srtm Data (*.tif *.tiff *.hgt)"), 0, QFileDialog::DontUseNativeDialog);
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
