@@ -36,7 +36,7 @@
 #include "CMenus.h"
 #include "CActions.h"
 #ifdef PLOT_3D
-#include "CMap3DWidget.h"
+#include "CMap3D.h"
 #endif
 
 #include <QtGui>
@@ -292,8 +292,11 @@ void CMegaMenu::mouseReleaseEvent(QMouseEvent * e)
     {
         if(rectF[i].contains(pos))
         {
-            acts[i]->trigger();
-            break;
+            if (acts.size() > i)
+            {
+                acts[i]->trigger();
+                break;
+            }
         }
     }
 
