@@ -116,7 +116,7 @@ QString COverlayDistance::getInfo()
 }
 
 
-bool COverlayDistance::isCloseEnought(const QPoint& pt)
+bool COverlayDistance::isCloseEnough(const QPoint& pt)
 {
     IMap& map = CMapDB::self().getMap();
     QList<XY>::iterator p = points.begin();
@@ -225,7 +225,6 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 {
     if(thePoint == 0) return;
 
-
     if(e->button() == Qt::LeftButton)
     {
         if(doMove)
@@ -277,7 +276,6 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
         else if(rectMove.contains(pos1))
         {
             QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMoveWpt"),0,0));
-            savePoint   = *thePoint;
             doMove      = true;
             doFuncWheel = false;
         }
@@ -332,15 +330,26 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
         {
             doMove      = false;
 
-            *thePoint   = savePoint;
-            thePoint    = 0;
+            points.removeOne(*thePoint);
+            thePoint = 0;
 
             calcDistance();
             theMainWindow->getCanvas()->update();
+            emit sigChanged();
+
+
+//            if (savePoint.u != OVL_NOFLOAT && savePoint.v != OVL_NOFLOAT)
+//            {
+//                *thePoint   = savePoint;
+//                thePoint    = 0;
+//
+//                calcDistance();
+//                theMainWindow->getCanvas()->update();
+//
+//                emit sigChanged();
+//            }
 
             QApplication::restoreOverrideCursor();
-
-            emit sigChanged();
             return;
         }
 
@@ -350,10 +359,10 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
 void COverlayDistance::mouseReleaseEvent(QMouseEvent * e)
 {
-//     QPoint pos = e->pos();
-//     IMap& map  = CMapDB::self().getMap();
-//
-//     emit sigChanged();
+    //     QPoint pos = e->pos();
+    //     IMap& map  = CMapDB::self().getMap();
+    //
+    //     emit sigChanged();
 }
 
 
@@ -472,6 +481,11 @@ void COverlayDistance::calcDistance()
 {
     distance = 0.0;
 
+    if(points.count() < 2)
+    {
+        return;
+    }
+
     double a1,a2;
     XY pt1, pt2;
     pt1 = points.first();
@@ -583,7 +597,6 @@ void COverlayDistance::slotToRoute()
 {
     if(points.isEmpty()) return;
 
-    IMap& map       = CMapDB::self().getDEM();
     CRoute * route  = new CRoute(&CRouteDB::self());
 
     route->setName(name);
@@ -642,3 +655,24 @@ void COverlayDistance::looseFocus()
     doMove          = false;
     doFuncWheel     = false;
 }
+
+
+QRectF COverlayDistance::getBoundingRectF()
+{
+    double north =  -90.0 * DEG_TO_RAD;
+    double south =  +90.0 * DEG_TO_RAD;
+    double west  = +180.0 * DEG_TO_RAD;
+    double east  = -180.0 * DEG_TO_RAD;
+
+    XY pt;
+    foreach(pt, points)
+    {
+        if(pt.u < west)  west  = pt.u;
+        if(pt.u > east)  east  = pt.u;
+        if(pt.v < south) south = pt.v;
+        if(pt.v > north) north = pt.v;
+    }
+
+    return QRectF(QPointF(west * RAD_TO_DEG,north * RAD_TO_DEG),QPointF(east * RAD_TO_DEG,south * RAD_TO_DEG));
+
+}
