@@ -39,7 +39,7 @@ class COverlayDistance : public IOverlay
         /// returns name, comment and length
         QString getInfo();
         /// returns true if pt is close as 30px to a waypoint
-        bool isCloseEnought(const QPoint& pt);
+        bool isCloseEnough(const QPoint& pt);
 
         /// draw the ployline, waypoints and action icons
         void draw(QPainter& p);
@@ -64,6 +64,8 @@ class COverlayDistance : public IOverlay
 
         void looseFocus();
 
+        QRectF getBoundingRectF();
+
     private slots:
         void slotToTrack();
         void slotToRoute();
@@ -79,8 +81,6 @@ class COverlayDistance : public IOverlay
         /// pointer to point of polyline if cursor is closer than 30px
         XY * thePoint;
 
-        XY savePoint;
-
         QString name;
         QString comment;
         double distance;
@@ -97,4 +97,7 @@ class COverlayDistance : public IOverlay
         double anglePrev;
         double angleNext;
 };
+
+#define OVL_NOFLOAT 1e25f
+
 #endif                           //COVERLAYDISTANCE_H
