@@ -142,7 +142,7 @@ void COverlayTextBox::draw(QPainter& p)
 }
 
 
-bool COverlayTextBox::isCloseEnought(const QPoint& pt)
+bool COverlayTextBox::isCloseEnough(const QPoint& pt)
 {
     QPolygon box = polyline;
 
@@ -337,3 +337,9 @@ void COverlayTextBox::makeVisible()
 {
     theMainWindow->getCanvas()->move(lon * RAD_TO_DEG, lat * RAD_TO_DEG);
 }
+
+
+QRectF COverlayTextBox::getBoundingRectF()
+{
+    return QRectF(lon * RAD_TO_DEG, lat * RAD_TO_DEG, 0.00001, 0.00001);
+}
