@@ -27,6 +27,10 @@
 #include <QDateTime>
 #include "CWpt.h"
 
+#ifdef GPX_EXTENSIONS
+#include "CGpxExtension.h"       //TODO: include von gpx ext
+#endif
+
 #define MAX_TRACK_SIZE 10000
 
 class CFlags
@@ -61,6 +65,10 @@ class CTrack : public QObject
         int ref;
         enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1};
 
+#ifdef GPX_EXTENSIONS
+        CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
+#endif
+
         struct pt_t
         {
             enum flag_e
@@ -76,7 +84,7 @@ class CTrack : public QObject
                 ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0),
                 fix(""), sat(0), velocity(WPT_NOFLOAT), heading(WPT_NOFLOAT),
                 vdop(WPT_NOFLOAT), hdop(WPT_NOFLOAT), pdop(WPT_NOFLOAT),
-                flags(0), px_valid(FALSE), dem(WPT_NOFLOAT), editItem(NULL) {}
+                flags(0), px_valid(FALSE), dem(WPT_NOFLOAT), editItem(NULL){}
 
             bool operator==(const pt_t& pt){return pt.idx == idx;}
 
@@ -131,6 +139,10 @@ class CTrack : public QObject
             float   vy;          ///< [m/s] velocity
             float   vz;          ///< [m/s] velocity
 
+#ifdef GPX_EXTENSIONS
+            CGpxExtPt gpx_exts;  //TODO: CGpxExtPt -> gpx_exts
+#endif
+
             /// display flags
             CFlags flags;
             /// the current location in pixel
@@ -198,6 +210,9 @@ class CTrack : public QObject
         bool hasExt1Data() { return ext1Data;};
         void setExt1Data() { ext1Data = true;};
 
+        void hide(bool ok);
+        bool isHidden(){return m_hide;}
+
         signals:
         void sigChanged();
 
@@ -251,6 +266,8 @@ class CTrack : public QObject
 
         bool firstTime;
 
+        bool m_hide;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CTrack& track);
