@@ -30,7 +30,7 @@
 #include "IMap.h"
 
 #include <QtGui>
-#include "CUndoStack.h"
+#include "CUndoStackModel.h"
 #include "CTrackUndoCommandDelete.h"
 #include "CTrackUndoCommandSelect.h"
 
@@ -49,16 +49,22 @@ CTrackDB * CTrackDB::m_self = 0;
 CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
 : IDB(tb,parent)
 , cnt(0)
+, showBullets(true)
 {
     m_self      = this;
+
+    QSettings cfg;
+    showBullets = cfg.value("tracks/showBullets", showBullets).toBool();
     toolview    = new CTrackToolWidget(tb);
-    undoStack = CUndoStack::getInstance();
+    undoStack   = CUndoStackModel::getInstance();
+
 }
 
 
 CTrackDB::~CTrackDB()
 {
-
+    QSettings cfg;
+    cfg.setValue("tracks/showBullets", showBullets);
 }
 
 
@@ -96,9 +102,11 @@ QRectF CTrackDB::getBoundingRectF()
     return r;
 }
 
+
 void CTrackDB::loadQLB(CQlb& qlb)
 {
     QDataStream stream(&qlb.tracks(),QIODevice::ReadOnly);
+    stream.setVersion(QDataStream::Qt_4_5);
 
     while(!stream.atEnd())
     {
@@ -112,10 +120,10 @@ void CTrackDB::loadQLB(CQlb& qlb)
 }
 
 
-
 void CTrackDB::loadQLB(CQlb& qlb, bool asDuplicat)
 {
     QDataStream stream(&qlb.tracks(),QIODevice::ReadOnly);
+    stream.setVersion(QDataStream::Qt_4_5);
 
     while(!stream.atEnd())
     {
@@ -301,6 +309,14 @@ void CTrackDB::loadGPX(CGpx& gpx)
                 tmpelem = trkptmap.value("extensions");
                 if(!tmpelem.isNull())
                 {
+#ifdef GPX_EXTENSIONS
+                                 //TODO: Abholen der Extension
+                    pt.gpx_exts.setValues(tmpelem);
+
+                                 //TODO: Auslesen der Namen der Ext
+                    track->tr_ext.addKey2List(tmpelem);
+#endif
+
                     QMap<QString,QDomElement> extensionsmap = CGpx::mapChildElements(tmpelem);
 
                     // Garmin extensions v3
@@ -605,6 +621,26 @@ void CTrackDB::highlightTrack(const QString& key)
 }
 
 
+void CTrackDB::hideTrack(const QStringList& keys, bool hide)
+{
+    QString key;
+    foreach(key, keys)
+    {
+        if(tracks.contains(key))
+        {
+            CTrack * track = tracks[key];
+            track->hide(hide);
+            if(track->isHighlighted() && hide)
+            {
+                tracks[key]->setHighlight(false);
+                emit sigHighlightTrack(tracks[key]);
+            }
+        }
+    }
+    emit sigChanged();
+}
+
+
 CTrack* CTrackDB::highlightedTrack()
 {
 
@@ -697,17 +733,19 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 {
     QPointF arrow[4] =
     {
-        QPointF( 15.0, 5.0),     //front
+        QPointF( 20.0, 7.0),     //front
         QPointF( 0.0, 0.0),      //upper tail
-        QPointF( 5.0, 5.0),      //mid tail
-        QPointF( 0.0, 10.0)      //lower tail
+        QPointF( 5.0, 7.0),      //mid tail
+        QPointF( 0.0, 15.0)      //lower tail
     };
 
     QPoint focus(-1,-1);
     QVector<QPoint> selected;
     IMap& map = CMapDB::self().getMap();
 
-    p.setRenderHint(QPainter::Antialiasing,false);
+    /// @todo it would be nice to use antialiasing here, but right now performance is bad
+    p.setRenderHint(QPainter::Antialiasing, !map.getFastDrawFlag());
+    p.setRenderHint(QPainter::Antialiasing, false);
 
     //     QMap<QString,CTrack*> tracks                = CTrackDB::self().getTracks();
     QMap<QString,CTrack*>::iterator track       = tracks.begin();
@@ -717,6 +755,14 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 
     while(track != tracks.end())
     {
+
+        if((*track)->m_hide)
+        {
+
+            ++track;
+            continue;
+        }
+
         QPolygon& line = (*track)->getPolyline();
         line.clear();
 
@@ -772,12 +818,17 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         else
         {
             // draw normal track
-            QPen pen((*track)->getColor(),3);
-            pen.setCapStyle(Qt::RoundCap);
-            pen.setJoinStyle(Qt::RoundJoin);
-            p.setPen(pen);
+            QPen pen1(Qt::white,5);
+            pen1.setCapStyle(Qt::RoundCap);
+            pen1.setJoinStyle(Qt::RoundJoin);
+
+            QPen pen2((*track)->getColor(),3);
+            pen2.setCapStyle(Qt::RoundCap);
+            pen2.setJoinStyle(Qt::RoundJoin);
+
+            p.setPen(pen1);
             p.drawPolyline(line);
-            p.setPen(Qt::white);
+            p.setPen(pen2);
             p.drawPolyline(line);
 
             // draw direction arrows
@@ -785,20 +836,16 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             bool    start = true;
             double  heading;
 
-            pen.setJoinStyle(Qt::MiterJoin);
-
             //generate arrow pic
-            // must be a little bigger or  createHeuristicMask won't work
-            QPixmap arrow_pic(16,11);
+            QImage arrow_pic(21,16, QImage::Format_ARGB32);
+            arrow_pic.fill( qRgba(0,0,0,0));
             QPainter t_paint(&arrow_pic);
             t_paint.setRenderHint(QPainter::Antialiasing, true);
-            t_paint.eraseRect(QRectF(0.,0.,16.,11.));
-            t_paint.setPen(Qt::black);
+            t_paint.setPen(QPen(Qt::white, 1));
             t_paint.setBrush((*track)->getColor());
             t_paint.drawPolygon(arrow, 4);
-            //t_paint.setRenderHint(QPainter::Antialiasing, false);
             t_paint.end();
-            arrow_pic.setMask(arrow_pic.createHeuristicMask());
+
 
             foreach(pt,line)
             {
@@ -820,7 +867,7 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
                             // draw arrow between bullets
                             p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
                             p.rotate(heading);
-                            p.drawPixmap(-9, -5, arrow_pic);
+                            p.drawImage(-11, -7, arrow_pic);
                             p.restore();
                                  //remember last point
                             ptt = pt;
@@ -840,42 +887,47 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
     {
         track = highlighted;
 
+        QPixmap bullet = (*track)->getBullet();
+
         QPolygon& line = (*track)->getPolyline();
 
         // draw skunk line
-        QPen pen((*track)->getColor(),5);
-        pen.setCapStyle(Qt::RoundCap);
-        pen.setJoinStyle(Qt::RoundJoin);
-        p.setPen(pen);
+        QPen pen1(Qt::white,11);
+        pen1.setCapStyle(Qt::RoundCap);
+        pen1.setJoinStyle(Qt::RoundJoin);
+
+        QPen pen2((*track)->getColor(),7);
+        pen2.setCapStyle(Qt::RoundCap);
+        pen2.setJoinStyle(Qt::RoundJoin);
+
+        p.setPen(pen1);
         p.drawPolyline(line);
-        p.setPen(Qt::white);
+        p.setPen(pen2);
         p.drawPolyline(line);
 
         // draw bubbles and direction arrows
         QPoint  pt, pt1, ptt;
         bool    start = true;
         double  heading;
-        QPixmap bullet = (*track)->getBullet();
-        pen.setJoinStyle(Qt::MiterJoin);
-        pen.setColor((*track)->getColor());
-        pen.setWidth(3);
-        //p.setPen(pen);
 
         //generate arrow pic
-        QPixmap arrow_pic(16,11);
+        QImage arrow_pic(21,15, QImage::Format_ARGB32);
+        arrow_pic.fill( qRgba(0,0,0,0));
         QPainter t_paint(&arrow_pic);
         t_paint.setRenderHint(QPainter::Antialiasing, true);
-        t_paint.eraseRect(QRectF(0.,0.,16.,11.));
-        t_paint.setPen(Qt::black);
+        t_paint.setPen(QPen(Qt::white, 2));
         t_paint.setBrush((*track)->getColor());
         t_paint.drawPolygon(arrow, 4);
         t_paint.end();
-        arrow_pic.setMask(arrow_pic.createHeuristicMask());
+
 
         foreach(pt,line)
         {
             if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7) continue;
-            p.drawPixmap(pt.x() - 3 ,pt.y() - 3, bullet);
+            if(showBullets)
+            {
+                p.drawPixmap(pt.x() - 3 ,pt.y() - 3, bullet);
+            }
 
             if(start)            // no arrow on  the first loop
             {
@@ -893,7 +945,7 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
                         // draw arrow between bullets
                         p.translate((pt.x() + pt1.x())/2, (pt.y() + pt1.y())/2);
                         p.rotate(heading);
-                        p.drawPixmap(-9, -5, arrow_pic);
+                        p.drawImage(-11, -7, arrow_pic);
                         p.restore();
                         ptt = pt;//remember last point
                     }
@@ -920,6 +972,8 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             p.drawLine(focus + QPoint(-20,0),focus + QPoint(20,0));
         }
     }
+
+    p.setRenderHint(QPainter::Antialiasing, false);
 }
 
 
@@ -1030,3 +1084,30 @@ void CTrackDB::emitSigModified()
 {
     emit sigModified();
 }
+
+
+void CTrackDB::revertTrack(const QString& key)
+{
+    if(!tracks.contains(key))
+    {
+        return;
+    }
+    CTrack *torg =  tracks[key];
+    CTrack *tnew = new CTrack(this);
+
+    tnew->name = torg->name + tr("_rev");
+
+    QList<CTrack::pt_t> track = torg->track;
+    while(track.size())
+    {
+        CTrack::pt_t pt = track.takeLast();
+
+        pt.timestamp        = 0;
+        pt.timestamp_msec   = 0;
+
+        *tnew << pt;
+    }
+
+    addTrack(tnew, false);
+
+}
