@@ -51,6 +51,7 @@ class CTrackDB : public IDB
         void delTracks(const QStringList& keys);
         void CombineTracks();
         void splitTrack(int idx);
+        void revertTrack(const QString& key);
 
         void highlightTrack(const QString& key);
         /// get highlighted track
@@ -64,6 +65,8 @@ class CTrackDB : public IDB
         */
         CTrack* highlightedTrack();
 
+        void hideTrack(const QStringList& keys, bool hide);
+
         /// get access to track dictionary
         const QMap<QString,CTrack*>& getTracks(){return tracks;}
 
@@ -84,6 +87,8 @@ class CTrackDB : public IDB
         void insert(const QString& key, CTrack *track, bool silent);
         void emitSigChanged();
         void emitSigModified();
+        void setShowBullets(bool on){showBullets = on; emit sigChanged();}
+        bool getShowBullets(){return showBullets;}
 
         signals:
         void sigHighlightTrack(CTrack * track);
@@ -100,5 +105,7 @@ class CTrackDB : public IDB
 
         QMap<QString,CTrack*> tracks;
         QUndoStack *undoStack;
+
+        bool showBullets;
 };
 #endif                           //CTRACKDB_H
