@@ -46,12 +46,20 @@ CTrackToolWidget::CTrackToolWidget(QTabWidget * parent)
     connect(listTracks,SIGNAL(itemClicked(QListWidgetItem*) ),this,SLOT(slotItemClicked(QListWidgetItem*)));
     connect(listTracks,SIGNAL(itemDoubleClicked(QListWidgetItem*) ),this,SLOT(slotItemDoubleClicked(QListWidgetItem*)));
 
-    contextMenu = new QMenu(this);
-    contextMenu->addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
-    contextMenu->addAction(QPixmap(":/icons/iconFilter16x16.png"),tr("Filter..."),this,SLOT(slotFilter()));
-    contextMenu->addAction(QPixmap(":/icons/iconDistance16x16.png"),tr("Make Overlay"),this,SLOT(slotToOverlay()));
-    contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Deselect"),this,SLOT(slotDelSelect()));
-    contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::Key_Delete);
+    contextMenu     = new QMenu(this);
+    actEdit         = contextMenu->addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
+    actFilter       = contextMenu->addAction(QPixmap(":/icons/iconFilter16x16.png"),tr("Filter..."),this,SLOT(slotFilter()));
+    actRevert       = contextMenu->addAction(QPixmap(":/icons/iconReload16x16.png"),tr("Revert"),this,SLOT(slotRevert()));
+    actDistance     = contextMenu->addAction(QPixmap(":/icons/iconDistance16x16.png"),tr("Make Overlay"),this,SLOT(slotToOverlay()));
+    actHide         = contextMenu->addAction(tr("Show"),this,SLOT(slotShow()));
+    actShowBullets  = contextMenu->addAction(tr("Show Bullets"),this,SLOT(slotShowBullets()));
+    actZoomToFit    = contextMenu->addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));
+    actDeSel        = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Deselect"),this,SLOT(slotDelSelect()));
+    actDel          = contextMenu->addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::Key_Delete);
+
+    actHide->setCheckable(true);
+    actShowBullets->setCheckable(true);
+    actShowBullets->setChecked(CTrackDB::self().getShowBullets());
 
     connect(listTracks,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 
@@ -83,6 +91,19 @@ void CTrackToolWidget::slotDBChanged()
         QListWidgetItem * item = new QListWidgetItem(listTracks);
         icon.fill((*track)->getColor());
 
+        QPainter p;
+        p.begin(&icon);
+
+        if((*track)->isHidden())
+        {
+            p.drawPixmap(0,0,QPixmap(":icons/iconClear16x16"));
+        }
+        else
+        {
+            p.drawPixmap(0,0,QPixmap(":icons/iconOk16x16"));
+        }
+        p.end();
+
         QString val1, unit1, val2, unit2;
 
         QString str     = (*track)->getName();
@@ -128,6 +149,8 @@ void CTrackToolWidget::slotDBChanged()
         ++track;
     }
 
+    listTracks->sortItems();
+
     if(highlighted)
     {
         listTracks->setCurrentItem(highlighted);
@@ -141,7 +164,9 @@ void CTrackToolWidget::slotItemDoubleClicked(QListWidgetItem * item)
 
     QRectF r = CTrackDB::self().getBoundingRectF(key);
     if (!r.isNull ())
+    {
         CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
 }
 
 
@@ -169,11 +194,32 @@ void CTrackToolWidget::keyPressEvent(QKeyEvent * e)
 
 void CTrackToolWidget::slotContextMenu(const QPoint& pos)
 {
-    if(listTracks->currentItem())
+    int cnt = listTracks->selectedItems().count();
+    if(cnt > 0)
     {
-        originator = true;
-        CTrackDB::self().highlightTrack(listTracks->currentItem()->data(Qt::UserRole).toString());
-        originator = false;
+        if(listTracks->currentItem())
+        {
+            originator = true;
+            CTrackDB::self().highlightTrack(listTracks->currentItem()->data(Qt::UserRole).toString());
+            originator = false;
+        }
+
+        if(cnt > 1)
+        {
+            actEdit->setEnabled(false);
+            actFilter->setEnabled(false);
+            actRevert->setEnabled(false);
+            actDeSel->setEnabled(false);
+        }
+        else
+        {
+            actEdit->setEnabled(true);
+            actFilter->setEnabled(true);
+            actRevert->setEnabled(true);
+            actDeSel->setEnabled(true);
+        }
+
+        actHide->setChecked(!CTrackDB::self().highlightedTrack()->isHidden());
 
         QPoint p = listTracks->mapToGlobal(pos);
         contextMenu->exec(p);
@@ -220,6 +266,19 @@ void CTrackToolWidget::slotDelete()
 }
 
 
+void CTrackToolWidget::slotShow()
+{
+    QStringList keys;
+    QListWidgetItem * item;
+    const QList<QListWidgetItem*>& items = listTracks->selectedItems();
+    foreach(item,items)
+    {
+        keys << item->data(Qt::UserRole).toString();
+    }
+    CTrackDB::self().hideTrack(keys, !actHide->isChecked());;
+}
+
+
 void CTrackToolWidget::slotDelSelect()
 {
     const QListWidgetItem* item = listTracks->currentItem();
@@ -280,3 +339,46 @@ void CTrackToolWidget::slotFilter()
     CDlgTrackFilter dlg(*track, this);
     dlg.exec();
 }
+
+
+void CTrackToolWidget::slotZoomToFit()
+{
+    QRectF r;
+
+    const QList<QListWidgetItem*>& items = listTracks->selectedItems();
+    QList<QListWidgetItem*>::const_iterator item = items.begin();
+
+    r = CTrackDB::self().getBoundingRectF((*item)->data(Qt::UserRole).toString());
+
+    while(item != items.end())
+    {
+        r |= CTrackDB::self().getBoundingRectF((*item)->data(Qt::UserRole).toString());
+        ++item;
+    }
+
+    if (!r.isNull ())
+    {
+        CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
+    }
+}
+
+
+void CTrackToolWidget::slotRevert()
+{
+    const QListWidgetItem* item = listTracks->currentItem();
+
+    if(item == 0)
+    {
+        QMessageBox::information(0,tr("Filter"), tr("You have to select a track first."), QMessageBox::Ok,QMessageBox::Ok);
+        return;
+    };
+
+    CTrackDB::self().revertTrack(item->data(Qt::UserRole).toString());
+}
+
+void CTrackToolWidget::slotShowBullets()
+{
+
+    CTrackDB::self().setShowBullets(!CTrackDB::self().getShowBullets());
+
+}
