@@ -26,6 +26,7 @@
 class QToolBox;
 class QListWidgetItem;
 class QMenu;
+class QAction;
 class CTrackEditWidget;
 
 class CTrackToolWidget : public QWidget, private Ui::ITrackToolWidget
@@ -50,6 +51,10 @@ class CTrackToolWidget : public QWidget, private Ui::ITrackToolWidget
         void slotDelete();
         void slotToOverlay();
         void slotFilter();
+        void slotShow();
+        void slotZoomToFit();
+        void slotRevert();
+        void slotShowBullets();
 
     private:
         bool originator;
@@ -58,5 +63,15 @@ class CTrackToolWidget : public QWidget, private Ui::ITrackToolWidget
 
         QPointer<CTrackEditWidget> trackedit;
 
+        QAction * actEdit;
+        QAction * actFilter;
+        QAction * actDistance;
+        QAction * actHide;
+        QAction * actZoomToFit;
+        QAction * actDeSel;
+        QAction * actDel;
+        QAction * actRevert;
+        QAction * actShowBullets;
+
 };
 #endif                           //CTRACKTOOLWIDGET_H
