@@ -107,6 +107,31 @@ void CWptDB::clear()
 }
 
 
+QList<CWptDB::keys_t> CWptDB::keys()
+{
+    QList<keys_t> k;
+
+    QString k1;
+    QStringList ks = wpts.keys();
+
+    foreach(k1, ks)
+    {
+        keys_t k2;
+
+        k2.key  = k1;
+        k2.name = wpts[k1]->name;
+        k2.icon = wpts[k1]->icon;
+        k2.lon  = wpts[k1]->lon;
+        k2.lat  = wpts[k1]->lat;
+        k2.d    = 0;
+
+        k << k2;
+    }
+
+    return k;
+}
+
+
 CWpt * CWptDB::newWpt(float lon, float lat, float ele)
 {
     CWpt * wpt = new CWpt(this);
@@ -177,7 +202,7 @@ void CWptDB::delWpt(const QStringList& keys, bool saveSticky)
 }
 
 
-void CWptDB::addWpt(CWpt * wpt)
+void CWptDB::addWpt(CWpt * wpt, bool silent)
 {
     if(wpts.contains(wpt->key()))
     {
@@ -193,8 +218,11 @@ void CWptDB::addWpt(CWpt * wpt)
     }
     wpts[wpt->key()] = wpt;
 
-    emit sigChanged();
-    emit sigModified();
+    if(!silent)
+    {
+        emit sigChanged();
+        emit sigModified();
+    }
 }
 
 
@@ -294,7 +322,7 @@ void CWptDB::loadGPX(CGpx& gpx)
             continue;
         }
 
-        addWpt(wpt);
+        addWpt(wpt, true);
     }
 
     emit sigChanged();
@@ -387,12 +415,13 @@ void CWptDB::saveGPX(CGpx& gpx)
 void CWptDB::loadQLB(CQlb& qlb)
 {
     QDataStream stream(&qlb.waypoints(),QIODevice::ReadOnly);
+    stream.setVersion(QDataStream::Qt_4_5);
 
     while(!stream.atEnd())
     {
         CWpt * wpt = new CWpt(this);
         stream >> *wpt;
-        addWpt(wpt);
+        addWpt(wpt,true);
     }
 
     emit sigChanged();
@@ -438,7 +467,7 @@ void CWptDB::download()
         CWpt * wpt;
         foreach(wpt,tmpwpts)
         {
-            addWpt(wpt);
+            addWpt(wpt,true);
         }
     }
 
@@ -562,6 +591,7 @@ static void exifContentForeachEntryFuncGPS(ExifEntry * exifEntry, void *user_dat
 
             break;
         }
+        default:;
     }
 }
 
@@ -581,7 +611,9 @@ static void exifContentForeachEntryFunc0(ExifEntry * exifEntry, void *user_data)
             exifGPS.timestamp   = timestamp.toTime_t();
             break;
         }
+        default:;
     }
+
 }
 
 
@@ -598,6 +630,8 @@ static void exifDataForeachContentFunc(ExifContent * exifContent, void * user_da
             f_exif_content_foreach_entry(exifContent, exifContentForeachEntryFuncGPS, user_data);
             break;
 
+        default:;
+
     }
     //     qDebug() << "***" << exif_content_get_ifd(exifContent) << "***";
     //     exif_content_dump(exifContent,0);
@@ -627,7 +661,7 @@ void CWptDB::createWaypointsFromImages()
 
     QDir dir(path);
     QStringList filter;
-    filter << "*.jpg" << "*.png";
+    filter << "*.jpg" << "*.jpeg" << "*.png";
     QStringList files = dir.entryList(filter, QDir::Files);
     QString file;
 
@@ -671,9 +705,11 @@ void CWptDB::createWaypointsFromImages()
         image.pixmap    = pixtmp.scaled(w,h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
         image.info      = file;
         wpt->images << image;
-        addWpt(wpt);
+        addWpt(wpt, true);
 
         f_exif_data_unref(exifData);
     }
+    emit sigChanged();
+    emit sigModified();
 }
 #endif
