@@ -19,6 +19,7 @@
 
 #include "Platform.h"
 #include "IGarminStrTbl.h"
+#include "QFileExt.h"
 
 #include <QtCore>
 
@@ -55,6 +56,19 @@ IGarminStrTbl::IGarminStrTbl(const quint16 codepage, const quint8 mask, QObject
             qDebug() << "unknown codepage:" << codepage << "0x" << hex << codepage;
         }
     }
+
+    mask32   = mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+    mask32 <<= 8;
+    mask32  |= mask;
+
+    mask64   = mask32;
+    mask64 <<= 32;
+    mask64  |= mask32;
+
 }
 
 
@@ -64,27 +78,50 @@ IGarminStrTbl::~IGarminStrTbl()
 }
 
 
-void IGarminStrTbl::readFile(QFile& file, quint32 offset, quint32 size, QByteArray& data)
+void IGarminStrTbl::readFile(QFileExt &file, quint32 offset, quint32 size, QByteArray& data)
 {
-    file.seek(offset);
-    data = file.read(size);
-
-    if((quint32)data.size() != size)
+    if(offset + size > file.size())
     {
         //         throw exce_t(eErrOpen, tr("Failed to read: ") + file.filename());
         return;
     }
 
-    quint8 * p = (quint8*)data.data();
-    for(quint32 i = 0; i < size; ++i)
+    // wenn mask == 0 ist kein xor noetig
+    if(mask == 0)
+    {
+        data = QByteArray::fromRawData(file.data(offset), size);
+        return;
+    }
+
+    // TODO: dieses copy is unnoetig
+    data = QByteArray(file.data(offset), size);
+
+#ifdef HOST_IS_64_BIT
+    quint64 * p64 = (quint64*)data.data();
+    for(quint32 i = 0; i < size/8; ++i)
+    {
+        *p64++ ^= mask64;
+    }
+    quint32 rest = size % 8;
+    quint8 * p = (quint8*)p64;
+#else
+    quint32 * p32 = (quint32*)data.data();
+    for(quint32 i = 0; i < size/4; ++i)
+    {
+        *p32++ ^= mask32;
+    }
+    quint32 rest = size % 4;
+    quint8 * p = (quint8*)p32;
+#endif
+
+    for(quint32 i = 0; i < rest; ++i)
     {
         *p++ ^= mask;
     }
-
 }
 
 
-quint32 IGarminStrTbl::calcOffset(QFile& file, const quint32 offset, type_e t)
+quint32 IGarminStrTbl::calcOffset(QFileExt& file, const quint32 offset, type_e t)
 {
     quint32 newOffset = offset;
 
