@@ -23,6 +23,7 @@
 #include "CMapDB.h"
 #include "CMapDEM.h"
 #include "IMapSelection.h"
+#include "GeoMath.h"
 
 #include <QtGui>
 #include <math.h>
@@ -39,6 +40,8 @@ IMap::IMap(maptype_e type, const QString& key, CCanvas * parent)
 , needsRedraw(true)
 , key(key)
 , doFastDraw(false)
+, angleNorth(0)
+, fastDrawWithoutTimer(false)
 {
     pjtar   = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
 
@@ -64,19 +67,45 @@ IMap::~IMap()
     qDebug() << "IMap::~IMap()";
     if(pjtar) pj_free(pjtar);
 
+    if(ovlMap)
+    {
+        delete ovlMap;
+    }
+
     QSettings cfg;
     cfg.setValue("map/zoom",zoomidx);
 }
 
 
+GDALDataset * IMap::getDataset()
+{
+    return 0;
+}
+
 void IMap::resize(const QSize& s)
 {
     size = s;
     rect.setSize(s);
-    buffer = QImage(size, QImage::Format_ARGB32);
+    buffer = QImage(size, QImage::Format_ARGB32_Premultiplied);
 
     needsRedraw = true;
     emit sigResize(s);
+
+    setAngleNorth();
+}
+
+
+void IMap::setAngleNorth()
+{
+    XY p1,p2;
+    double d, a1 = 0, a2 = 0;
+    p2.u = p1.u = rect.center().x();
+    p2.v = p1.v = rect.bottom();
+    p2.v -= 400;
+    convertPt2Rad(p1.u, p1.v);
+    convertPt2Rad(p2.u, p2.v);
+    d = distance(p1, p2, a1, a2);
+    angleNorth = a1;
 }
 
 
@@ -267,13 +296,16 @@ bool IMap::hasOverlayMap(const QString& k)
 }
 
 
-void IMap::setFastDraw()
+void IMap::setFastDrawTimer()
 {
-    timerFastDraw->start(500);
+    if(fastDrawWithoutTimer)
+    {
+        return;
+    }
+    timerFastDraw->start(300);
     doFastDraw = true;
 }
 
-
 void IMap::slotResetFastDraw()
 {
     needsRedraw = true;
@@ -282,6 +314,21 @@ void IMap::slotResetFastDraw()
 }
 
 
+void IMap::fastDrawOn()
+{
+    doFastDraw = true;
+    fastDrawWithoutTimer = true;
+}
+
+void IMap::fastDrawOff()
+{
+    needsRedraw = true;
+    doFastDraw  = false;
+    fastDrawWithoutTimer = false;
+    emit sigChanged();
+}
+
+
 bool IMap::isLonLat()
 {
     if(pjsrc)
@@ -296,3 +343,25 @@ void IMap::select(IMapSelection& ms, const QRect& rect)
 {
     throw tr("This map does not support this feature.");
 }
+
+
+void IMap::incXOffset(int i)
+{
+    QMessageBox::warning(0, tr("Error..."),tr("Changing the offset is not supported by this map."),QMessageBox::Abort,QMessageBox::Abort);
+}
+
+
+void IMap::decXOffset(int i)
+{
+    QMessageBox::warning(0, tr("Error..."),tr("Changing the offset is not supported by this map."),QMessageBox::Abort,QMessageBox::Abort);
+}
+
+void IMap::incYOffset(int i)
+{
+    QMessageBox::warning(0, tr("Error..."),tr("Changing the offset is not supported by this map."),QMessageBox::Abort,QMessageBox::Abort);
+}
+
+void IMap::decYOffset(int i)
+{
+    QMessageBox::warning(0, tr("Error..."),tr("Changing the offset is not supported by this map."),QMessageBox::Abort,QMessageBox::Abort);
+}
