@@ -35,6 +35,7 @@ class QPainter;
 class CCanvas;
 class CMapDEM;
 class IMapSelection;
+class GDALDataset;
 
 /// base class to any map render object
 class IMap : public QObject
@@ -216,7 +217,7 @@ class IMap : public QObject
          * \param h - matrix height
          * @return - return new buffer with size w * h
          */
-        virtual qint16 *getOrigRegion(XY &topLeft, XY &bottomRight, int& width, int& height) { return NULL; };
+        virtual bool getOrigRegion(QVector<qint16>& data, XY &topLeft, XY &bottomRight, int& width, int& height) { return false; };
         /**
          * get values for the defined region.
          * \param buffer - elevation matrix. It must has size w * h.
@@ -225,7 +226,7 @@ class IMap : public QObject
          * \param w - matrix width
          * \param h - matrix height
          */
-        virtual void getRegion(float *buffer, XY topLeft, XY bottomRight, int width, int height) {};
+        virtual bool getRegion(QVector<float>& buffer, XY topLeft, XY bottomRight, int width, int height) {return false;}
         /// return the state of the needsRedraw flag
         virtual bool getNeedsRedraw(){return needsRedraw;}
         /// the map type, hast to be set during construction
@@ -237,11 +238,26 @@ class IMap : public QObject
         /// summon a configuration dialog, dafault does nothing
         virtual void config(){};
 
+        /// return true if the map uses 32 bit color
         virtual bool is32BitRgb(){return true;}
 
+        /// return the angle of the true north compared to the vertical axis of the map []
+        virtual double getAngleNorth(){return angleNorth;}
+
+        virtual void fastDrawOn();
+        virtual void fastDrawOff();
+
+        /// get access to the used GDAL dataset
+        /**
+            Not sure if that is a good idea. But for now there is no better.
+        */
+        virtual GDALDataset * getDataset();
+
         static double midU;
         static double midV;
 
+
+
         signals:
         void sigChanged();
         void sigResize(const QSize& size);
@@ -253,6 +269,10 @@ class IMap : public QObject
         */
         virtual void resize(const QSize& size);
 
+        virtual void incXOffset(int i);
+        virtual void incYOffset(int i);
+        virtual void decXOffset(int i);
+        virtual void decYOffset(int i);
     protected slots:
         /// called by timerFastDraw to reset doFastDraw flag
         virtual void slotResetFastDraw();
@@ -262,7 +282,9 @@ class IMap : public QObject
     protected:
         virtual void getArea_n_Scaling(XY& p1, XY& p2, float& my_xscale, float& my_yscale){};
         virtual void getArea_n_Scaling_fromBase(XY& p1, XY& p2, float& my_xscale, float& my_yscale);
-        virtual void setFastDraw();
+        virtual void setFastDrawTimer();
+
+        void setAngleNorth();
 
         QString filename;
         /// canvas / viewport rectangle [px]
@@ -294,5 +316,10 @@ class IMap : public QObject
 
         bool doFastDraw;
         QTimer * timerFastDraw;
+
+        double angleNorth;
+
+    private:
+        bool fastDrawWithoutTimer;
 };
 #endif                           //IMAP_H
