@@ -49,7 +49,7 @@ class IOverlay : public QObject
         /// return a short string to be displayed in a list widget
         virtual QString getInfo(){return tr("No info set");}
         /// return true if coursor is close to the overlay to redirect mouse events into the overlay
-        virtual bool isCloseEnought(const QPoint& pt) = 0;
+        virtual bool isCloseEnough(const QPoint& pt) = 0;
         /// return true if some mouse action is in progress
         /**
             Some mouse actions will leave the rectangle returend by getRect(). However the
@@ -80,6 +80,8 @@ class IOverlay : public QObject
 
         virtual void looseFocus(){};
 
+        virtual QRectF getBoundingRectF(){return QRectF();}
+
         /// the overlay type as string
         const QString type;
         /// the overlay icon
